@@ -1,7 +1,11 @@
-// conf.cpp -- Set up configuration information and static data.
-//
-// $Id: conf.cpp,v 1.71 2006/05/18 18:43:44 sdennis Exp $
-//
+/*! \file conf.cpp
+ *  Set up configuration information and static data.
+ *
+ * $Id: conf.cpp 2969 2007-12-22 23:32:11Z brazilofmux $
+ *
+ * This parses the configuration files and controls configuration options used
+ * to control the server and its behavior.
+ */
 
 #include "copyright.h"
 #include "autoconf.h"
@@ -17,11 +21,11 @@
 //
 typedef struct confparm
 {
-    char *pname;            // parm name
+    const char *pname;      // parm name
     int (*interpreter)(int *vp, char *str, void *pExtra, UINT32 nExtra,
                        dbref player, char *cmd); // routine to interp parameter
     int flags;              // control flags
-    int rperms;             // read permissino flags.
+    int rperms;             // read permission flags.
     int *loc;               // where to store value
     void *pExtra;           // extra pointer for interpreter
     UINT32 nExtra;          // extra data for interpreter
@@ -56,15 +60,21 @@ void cf_init(void)
 
     mudconf.ports.n = 1;
     mudconf.ports.pi = (int *)MEMALLOC(sizeof(int));
-    ISOUTOFMEMORY(mudconf.ports.pi);
-    mudconf.ports.pi[0] = 2860;
+    if (mudconf.ports.pi)
+    {
+        mudconf.ports.pi[0] = 2860;
+    }
+    else
+    {
+        ISOUTOFMEMORY(mudconf.ports.pi);
+    }
 
     mudconf.init_size = 1000;
     mudconf.guest_char = -1;
     mudconf.guest_nuker = GOD;
     mudconf.number_guests = 30;
     mudconf.min_guests = 1;
-    strcpy(mudconf.guest_prefix, "Guest");
+    mux_strncpy(mudconf.guest_prefix, "Guest", 31);
     mudconf.guest_file     = StringClone("text/guest.txt");
     mudconf.conn_file      = StringClone("text/connect.txt");
     mudconf.creg_file      = StringClone("text/register.txt");
@@ -84,11 +94,23 @@ void cf_init(void)
     mudconf.postdump_msg[0] = '\0';
     mudconf.fixed_home_msg[0] = '\0';
     mudconf.fixed_tel_msg[0] = '\0';
-    strcpy(mudconf.public_channel, "Public");
-    strcpy(mudconf.public_channel_alias, "pub");
-    strcpy(mudconf.guests_channel, "Guests");
-    strcpy(mudconf.guests_channel_alias, "g");
-    strcpy(mudconf.pueblo_msg, "</xch_mudtext><img xch_mode=html>");
+    mux_strncpy(mudconf.public_channel, "Public", 31);
+    mux_strncpy(mudconf.public_channel_alias, "pub", 31);
+    mux_strncpy(mudconf.guests_channel, "Guests", 31);
+    mux_strncpy(mudconf.guests_channel_alias, "g", 31);
+    mux_strncpy(mudconf.pueblo_msg, "</xch_mudtext><img xch_mode=html>", GBUF_SIZE-1);
+#if defined(FIRANMUX)
+    mux_strncpy(mudconf.immobile_msg, "You have been set immobile.", sizeof(mudconf.immobile_msg)-1);
+    mudconf.sql_server[0]   = '\0';
+    mudconf.sql_user[0]     = '\0';
+    mudconf.sql_password[0] = '\0';
+    mudconf.sql_database[0] = '\0';
+    mudconf.mail_server[0]  = '\0';
+    mudconf.mail_ehlo[0]    = '\0';
+    mudconf.mail_sendaddr[0]= '\0';
+    mudconf.mail_sendname[0]= '\0';
+    mudconf.mail_subject[0] = '\0';
+#endif // FIRANMUX
     mudconf.art_rules = NULL;
     mudconf.indent_desc = false;
     mudconf.name_spaces = true;
@@ -129,7 +151,7 @@ void cf_init(void)
     mudconf.def_exit_tx = 1;
     mudconf.def_thing_rx = 1;
     mudconf.def_thing_tx = 1;
-#endif /* REALITY_LVLS */
+#endif // REALITY_LVLS
     mudconf.start_quota = 20;
     mudconf.site_chars = 25;
     mudconf.payfind = 0;
@@ -157,6 +179,7 @@ void cf_init(void)
     mudconf.sacfactor       = 5;
     mudconf.sacadjust       = -1;
     mudconf.trace_limit     = 200;
+    mudconf.float_precision = -1;
 
     mudconf.autozone        = true;
     mudconf.use_hostname    = true;
@@ -207,13 +230,17 @@ void cf_init(void)
         mudconf.exit_flags.word[i] = 0;
         mudconf.thing_flags.word[i] = 0;
         mudconf.robot_flags.word[i] = 0;
+        mudconf.stripped_flags.word[i] = 0;
     }
     mudconf.robot_flags.word[FLAG_WORD1] |= ROBOT;
+    mudconf.stripped_flags.word[FLAG_WORD1] = IMMORTAL | INHERIT | ROYALTY | WIZARD;
+    mudconf.stripped_flags.word[FLAG_WORD2] = BLIND | CONNECTED | GAGGED
+         | HEAD_FLAG | SLAVE | STAFF | SUSPECT | UNINSPECTED;
 
     mudconf.vattr_flags = AF_ODARK;
-    strcpy(mudconf.mud_name, "MUX");
-    strcpy(mudconf.one_coin, "penny");
-    strcpy(mudconf.many_coins, "pennies");
+    mux_strncpy(mudconf.mud_name, "MUX", 31);
+    mux_strncpy(mudconf.one_coin, "penny", 31);
+    mux_strncpy(mudconf.many_coins, "pennies", 31);
     mudconf.timeslice.SetSeconds(1);
     mudconf.cmd_quota_max = 100;
     mudconf.cmd_quota_incr = 1;
@@ -255,6 +282,7 @@ void cf_init(void)
     mudconf.mail_per_hour = 50;
     mudconf.vattr_per_hour = 5000;
     mudconf.pcreate_per_hour = 100;
+    mudconf.lbuf_size = LBUF_SIZE;
 
     mudstate.events_flag = 0;
     mudstate.bReadingConfiguration = false;
@@ -269,7 +297,7 @@ void cf_init(void)
     mudstate.attr_next = A_USER_START;
     mudstate.debug_cmd = "< init >";
     mudstate.curr_cmd  = "< none >";
-    strcpy(mudstate.doing_hdr, "Doing");
+    mux_strncpy(mudstate.doing_hdr, "Doing", SIZEOF_DOING_STRING-1);
     mudstate.access_list = NULL;
     mudstate.suspect_list = NULL;
     mudstate.badname_head = NULL;
@@ -313,7 +341,6 @@ void cf_init(void)
     for (i = 0; i < MAX_GLOBAL_REGS; i++)
     {
         mudstate.global_regs[i] = NULL;
-        mudstate.glob_reg_len[i] = 0;
     }
     mudstate.nObjEvalNest = 0;
     mudstate.in_loop = 0;
@@ -328,7 +355,7 @@ void cf_init(void)
 // ---------------------------------------------------------------------------
 // cf_log_notfound: Log a 'parameter not found' error.
 //
-void cf_log_notfound(dbref player, char *cmd, const char *thingname, char *thing)
+void cf_log_notfound(dbref player, const char *cmd, const char *thingname, const char *thing)
 {
     if (mudstate.bReadingConfiguration)
     {
@@ -390,7 +417,7 @@ static int cf_status_from_succfail(dbref player, char *cmd, int success, int fai
         {
             STARTLOG(LOG_STARTUP, "CNF", "NDATA")
             buff = alloc_lbuf("cf_status_from_succfail.LOG");
-            sprintf(buff, "%s: Nothing to set", cmd);
+            mux_sprintf(buff, LBUF_SIZE, "%s: Nothing to set", cmd);
             log_text(buff);
             free_lbuf(buff);
             ENDLOG
@@ -433,7 +460,7 @@ CF_HAND(cf_rlevel)
     mc->no_levels++;
     return 0;
 }
-#endif /* REALITY_LVLS */
+#endif // REALITY_LVLS
 
 // ---------------------------------------------------------------------------
 // cf_int_array: Setup array of integers.
@@ -444,44 +471,70 @@ static CF_HAND(cf_int_array)
     UNUSED_PARAMETER(player);
     UNUSED_PARAMETER(cmd);
 
-    int *aPorts = (int *)MEMALLOC(nExtra*sizeof(int));
-    ISOUTOFMEMORY(aPorts);
-    unsigned int nPorts = 0;
+    int *aPorts = NULL;
+    try
+    {
+        aPorts = new int[nExtra];
+    }
+    catch (...)
+    {
+        ; // Nothing.
+    }
 
+    if (NULL == aPorts)
+    {
+        cf_log_syntax(player, cmd, "Out of memory.");
+        return -1;
+    }
+
+    unsigned int nPorts = 0;
     char *p;
     MUX_STRTOK_STATE tts;
     mux_strtok_src(&tts, str);
     mux_strtok_ctl(&tts, " \t\n\r");
-    while ((p = mux_strtok_parse(&tts)) != NULL)
+    while (  (p = mux_strtok_parse(&tts)) != NULL
+          && nPorts < nExtra)
     {
         int unused;
         if (is_integer(p, &unused))
         {
             aPorts[nPorts++] = mux_atol(p);
-            if (nPorts >= nExtra)
-            {
-                break;
-            }
         }
     }
 
     IntArray *pia = (IntArray *)vp;
     if (nPorts)
     {
+        int *q = NULL;
+        try
+        {
+            q = new int[nPorts];
+        }
+        catch (...)
+        {
+            ; // Nothing.
+        }
+
+        if (NULL == q)
+        {
+            cf_log_syntax(player, cmd, "Out of memory.");
+            return -1;
+        }
+
         if (pia->pi)
         {
-            MEMFREE(pia->pi);
+            delete [] pia->pi;
             pia->pi = NULL;
         }
-        pia->pi = (int *)MEMALLOC(nPorts * sizeof(int));
-        ISOUTOFMEMORY(pia->pi);
+
+        pia->pi = q;
         pia->n = nPorts;
         for (unsigned int i = 0; i < nPorts; i++)
         {
             pia->pi[i] = aPorts[i];
         }
     }
-    MEMFREE(aPorts);
+    delete [] aPorts;
     return 0;
 }
 
@@ -609,7 +662,7 @@ static CF_HAND(cf_string)
     // Copy the string to the buffer if it is not too big.
     //
     int retval = 0;
-    unsigned int nStr = strlen(str);
+    size_t nStr = strlen(str);
     if (nStr >= nExtra)
     {
         nStr = nExtra - 1;
@@ -667,7 +720,7 @@ static CF_HAND(cf_string_dyn)
     // then there is a size limitation as well.
     //
     int retval = 0;
-    unsigned int nStr = strlen(str);
+    size_t nStr = strlen(str);
     if (nExtra && nStr >= nExtra)
     {
         nStr = nExtra - 1;
@@ -748,6 +801,14 @@ static CF_HAND(cf_flagalias)
     char *alias = mux_strtok_parse(&tts);
     char *orig = mux_strtok_parse(&tts);
 
+    if (  NULL == alias
+       || '\0' == alias[0]
+       || NULL == orig
+       || '\0' == orig[0])
+    {
+        return -1;
+    }
+
     bool success = false;
     int  nName;
     bool bValid;
@@ -791,6 +852,14 @@ static CF_HAND(cf_poweralias)
     char *alias = mux_strtok_parse(&tts);
     char *orig = mux_strtok_parse(&tts);
 
+    if (  NULL == alias
+       || '\0' == alias[0]
+       || NULL == orig
+       || '\0' == orig[0])
+    {
+        return -1;
+    }
+
     bool success = false;
     int  nName;
     bool bValid;
@@ -1389,8 +1458,21 @@ static CF_HAND(cf_site)
 
     // Parse the access entry and allocate space for it.
     //
-    SITE *site = (SITE *)MEMALLOC(sizeof(SITE));
-    ISOUTOFMEMORY(site);
+    SITE *site = NULL;
+    try
+    {
+        site = new SITE;
+    }
+    catch (...)
+    {
+        ; // Nothing.
+    }
+
+    if (NULL == site)
+    {
+        cf_log_syntax(player, cmd, "Out of memory.");
+        return -1;
+    }
 
     // Initialize the site entry.
     //
@@ -1467,18 +1549,43 @@ static int add_helpfile(dbref player, char *cmd, char *str, bool bRaw)
     {
         mudstate.mHelpDesc = 4;
         mudstate.nHelpDesc = 0;
-        mudstate.aHelpDesc = (HELP_DESC *)MEMALLOC(sizeof(HELP_DESC)
-            *mudstate.mHelpDesc);
-        ISOUTOFMEMORY(mudstate.aHelpDesc);
+        try
+        {
+            mudstate.aHelpDesc = new HELP_DESC[mudstate.mHelpDesc];
+        }
+        catch (...)
+        {
+            ; // Nothing.
+        }
+
+        if (NULL == mudstate.aHelpDesc)
+        {
+            cf_log_syntax(player, cmd, "Out of memory.");
+            return -1;
+        }
     }
     else if (mudstate.mHelpDesc <= mudstate.nHelpDesc)
     {
         int newsize = mudstate.mHelpDesc + 4;
-        HELP_DESC *q = (HELP_DESC *)MEMALLOC(sizeof(HELP_DESC)*newsize);
-        ISOUTOFMEMORY(q);
+        HELP_DESC *q = NULL;
+        try
+        {
+            q = new HELP_DESC[newsize];
+        }
+        catch (...)
+        {
+            ; // Nothing.
+        }
+
+        if (NULL == mudstate.aHelpDesc)
+        {
+            cf_log_syntax(player, cmd, "Out of memory.");
+            return -1;
+        }
+
         memset(q, 0, sizeof(HELP_DESC)*newsize);
         memcpy(q, mudstate.aHelpDesc, sizeof(HELP_DESC)*mudstate.mHelpDesc);
-        MEMFREE(mudstate.aHelpDesc);
+        delete [] mudstate.aHelpDesc;
         mudstate.aHelpDesc = q;
         mudstate.mHelpDesc = newsize;
     }
@@ -1493,28 +1600,43 @@ static int add_helpfile(dbref player, char *cmd, char *str, bool bRaw)
 
     // Build up Command Entry.
     //
-    CMDENT_ONE_ARG *cmdp = (CMDENT_ONE_ARG *)MEMALLOC(sizeof(CMDENT_ONE_ARG));
-    ISOUTOFMEMORY(cmdp);
+    CMDENT_ONE_ARG *cmdp = NULL;
+    try
+    {
+        cmdp = new CMDENT_ONE_ARG;
+    }
+    catch (...)
+    {
+        ; // Nothing.
+    }
 
-    cmdp->callseq = CS_ONE_ARG;
-    cmdp->cmdname = StringClone(pCmdName);
-    cmdp->extra = mudstate.nHelpDesc;
-    cmdp->handler = do_help;
-    cmdp->hookmask = 0;
-    cmdp->perms = CA_PUBLIC;
-    cmdp->switches = NULL;
+    if (NULL != cmdp)
+    {
+        cmdp->callseq = CS_ONE_ARG;
+        cmdp->cmdname = StringClone(pCmdName);
+        cmdp->extra = mudstate.nHelpDesc;
+        cmdp->handler = do_help;
+        cmdp->hookmask = 0;
+        cmdp->perms = CA_PUBLIC;
+        cmdp->switches = NULL;
 
-    // TODO: If a command is deleted with one or both of the two
-    // hashdeleteLEN() calls below, what guarantee do we have that parts of
-    // the command weren't dynamically allocated.  This might leak memory.
-    //
-    char *p = cmdp->cmdname;
-    hashdeleteLEN(p, strlen(p), &mudstate.command_htab);
-    hashaddLEN(p, strlen(p), cmdp, &mudstate.command_htab);
+        // TODO: If a command is deleted with one or both of the two
+        // hashdeleteLEN() calls below, what guarantee do we have that parts
+        // of the command weren't dynamically allocated.  This might leak
+        // memory.
+        //
+        const char *p = cmdp->cmdname;
+        hashdeleteLEN(p, strlen(p), &mudstate.command_htab);
+        hashaddLEN(p, strlen(p), cmdp, &mudstate.command_htab);
 
-    p = tprintf("__%s", cmdp->cmdname);
-    hashdeleteLEN(p, strlen(p), &mudstate.command_htab);
-    hashaddLEN(p, strlen(p), cmdp, &mudstate.command_htab);
+        p = tprintf("__%s", cmdp->cmdname);
+        hashdeleteLEN(p, strlen(p), &mudstate.command_htab);
+        hashaddLEN(p, strlen(p), cmdp, &mudstate.command_htab);
+    }
+    else
+    {
+        ISOUTOFMEMORY(cmdp);
+    }
 
     mudstate.nHelpDesc++;
 
@@ -1568,7 +1690,7 @@ static CF_HAND(cf_hook)
 
     int retval = -1;
     memset(playbuff, '\0', sizeof(playbuff));
-    strncpy(playbuff, str, 200);
+    mux_strncpy(playbuff, str, 200);
     MUX_STRTOK_STATE tts;
     mux_strtok_src(&tts, playbuff);
     mux_strtok_ctl(&tts, " \t");
@@ -1587,7 +1709,7 @@ static CF_HAND(cf_hook)
     }
 
     *vp = cmdp->hookmask;
-    strncpy(playbuff, str, 200);
+    mux_strncpy(playbuff, str, 200);
     hookptr = mux_strtok_parse(&tts);
     while (hookptr != NULL)
     {
@@ -1628,8 +1750,8 @@ static CF_HAND(cf_include)
         return -1;
     }
 
-    FILE *fp = fopen(str, "rb");
-    if (fp == NULL)
+    FILE *fp;
+    if (!mux_fopen(&fp, str, "rb"))
     {
         cf_log_notfound(player, cmd, "Config file", str);
         return -1;
@@ -1637,7 +1759,10 @@ static CF_HAND(cf_include)
     DebugTotalFiles++;
 
     char *buf = alloc_lbuf("cf_include");
-    fgets(buf, LBUF_SIZE, fp);
+    if (NULL == fgets(buf, LBUF_SIZE, fp))
+    {
+        return 0;
+    }
     while (!feof(fp))
     {
         char *zp = buf;
@@ -1707,7 +1832,11 @@ static CF_HAND(cf_include)
         {
             cf_set(cp, ap, player);
         }
-        fgets(buf, LBUF_SIZE, fp);
+
+        if (NULL == fgets(buf, LBUF_SIZE, fp))
+        {
+            break;
+        }
     }
     free_lbuf(buf);
     if (fclose(fp) == 0)
@@ -1758,7 +1887,7 @@ static CONF conftable[] =
     {"down_file",                 cf_string_dyn,  CA_STATIC, CA_GOD,      (int *)&mudconf.down_file,       NULL, SIZEOF_PATHNAME},
     {"down_motd_message",         cf_string,      CA_GOD,    CA_WIZARD,   (int *)mudconf.downmotd_msg,     NULL,       GBUF_SIZE},
     {"dump_interval",             cf_int,         CA_GOD,    CA_WIZARD,   &mudconf.dump_interval,          NULL,               0},
-    {"dump_message",              cf_string,      CA_GOD,    CA_WIZARD,   (int *)mudconf.dump_msg,         NULL,             128},
+    {"dump_message",              cf_string,      CA_GOD,    CA_WIZARD,   (int *)mudconf.dump_msg,         NULL,             256},
     {"dump_offset",               cf_int,         CA_GOD,    CA_WIZARD,   &mudconf.dump_offset,            NULL,               0},
     {"earn_limit",                cf_int,         CA_GOD,    CA_PUBLIC,   &mudconf.paylimit,               NULL,               0},
     {"eval_comtitle",             cf_bool,        CA_GOD,    CA_PUBLIC,   (int *)&mudconf.eval_comtitle,   NULL,               0},
@@ -1774,6 +1903,7 @@ static CONF conftable[] =
     {"flag_access",               cf_flag_access, CA_GOD,    CA_DISABLED, NULL,                            NULL,               0},
     {"flag_alias",                cf_flagalias,   CA_GOD,    CA_DISABLED, NULL,                            NULL,               0},
     {"flag_name",                 cf_flag_name,   CA_GOD,    CA_DISABLED, NULL,                            NULL,               0},
+    {"float_precision",           cf_int,         CA_STATIC, CA_PUBLIC,   &mudconf.float_precision,        NULL,               0},
     {"forbid_site",               cf_site,        CA_GOD,    CA_DISABLED, (int *)&mudstate.access_list,    NULL,     H_FORBIDDEN},
 #ifndef WIN32
     {"fork_dump",                 cf_bool,        CA_GOD,    CA_WIZARD,   (int *)&mudconf.fork_dump,       NULL,               0},
@@ -1813,6 +1943,7 @@ static CONF conftable[] =
     {"kill_max_cost",             cf_int,         CA_GOD,    CA_PUBLIC,   &mudconf.killmax,                NULL,               0},
     {"kill_min_cost",             cf_int,         CA_GOD,    CA_PUBLIC,   &mudconf.killmin,                NULL,               0},
     {"lag_maximum",               cf_seconds,     CA_GOD,    CA_WIZARD,   (int *)&mudconf.rpt_cmdsecs,     NULL,               0},
+    {"lbuf_size",                 cf_int,       CA_DISABLED, CA_PUBLIC,   (int *)&mudconf.lbuf_size,       NULL,               0},
     {"link_cost",                 cf_int,         CA_GOD,    CA_PUBLIC,   &mudconf.linkcost,               NULL,               0},
     {"list_access",               cf_ntab_access, CA_GOD,    CA_DISABLED, (int *)list_names,               access_nametab,     0},
     {"lock_recursion_limit",      cf_int,         CA_WIZARD, CA_PUBLIC,   &mudconf.lock_nest_lim,          NULL,               0},
@@ -1841,7 +1972,7 @@ static CONF conftable[] =
     {"number_guests",             cf_int,         CA_STATIC, CA_WIZARD,   &mudconf.number_guests,          NULL,               0},
     {"open_cost",                 cf_int,         CA_GOD,    CA_PUBLIC,   &mudconf.opencost,               NULL,               0},
     {"output_database",           cf_string_dyn,  CA_STATIC, CA_GOD,      (int *)&mudconf.outdb,           NULL, SIZEOF_PATHNAME},
-    {"output_limit",              cf_int,         CA_GOD,    CA_WIZARD,   &mudconf.output_limit,           NULL,               0},
+    {"output_limit",              cf_int,         CA_GOD,    CA_WIZARD,   (int *)&mudconf.output_limit,           NULL,               0},
     {"page_cost",                 cf_int,         CA_GOD,    CA_PUBLIC,   &mudconf.pagecost,               NULL,               0},
     {"paranoid_allocate",         cf_bool,        CA_GOD,    CA_WIZARD,   (int *)&mudconf.paranoid_alloc,  NULL,               0},
     {"parent_recursion_limit",    cf_int,         CA_GOD,    CA_PUBLIC,   &mudconf.parent_nest_lim,        NULL,               0},
@@ -1858,7 +1989,7 @@ static CONF conftable[] =
     {"player_starting_home",      cf_dbref,       CA_GOD,    CA_PUBLIC,   &mudconf.start_home,             NULL,               0},
     {"player_starting_room",      cf_dbref,       CA_GOD,    CA_PUBLIC,   &mudconf.start_room,             NULL,               0},
     {"port",                      cf_int_array,   CA_STATIC, CA_PUBLIC,   (int *)&mudconf.ports,           NULL, MAX_LISTEN_PORTS},
-    {"postdump_message",          cf_string,      CA_GOD,    CA_WIZARD,   (int *)mudconf.postdump_msg,     NULL,             128},
+    {"postdump_message",          cf_string,      CA_GOD,    CA_WIZARD,   (int *)mudconf.postdump_msg,     NULL,             256},
     {"power_alias",               cf_poweralias,  CA_GOD,    CA_DISABLED, NULL,                            NULL,               0},
     {"pcreate_per_hour",          cf_int,         CA_STATIC, CA_PUBLIC,   (int *)&mudconf.pcreate_per_hour,NULL,               0},
     {"public_channel",            cf_string,      CA_STATIC, CA_PUBLIC,   (int *)mudconf.public_channel,   NULL,              32},
@@ -1898,6 +2029,7 @@ static CONF conftable[] =
     {"starting_money",            cf_int,         CA_GOD,    CA_PUBLIC,   &mudconf.paystart,               NULL,               0},
     {"starting_quota",            cf_int,         CA_GOD,    CA_PUBLIC,   &mudconf.start_quota,            NULL,               0},
     {"status_file",               cf_string_dyn,  CA_STATIC, CA_GOD,      (int *)&mudconf.status_file,     NULL, SIZEOF_PATHNAME},
+    {"stripped_flags",            cf_set_flags,   CA_GOD,    CA_DISABLED, (int *)&mudconf.stripped_flags,  NULL,               0},
     {"suspect_site",              cf_site,        CA_GOD,    CA_DISABLED, (int *)&mudstate.suspect_list,   NULL,       H_SUSPECT},
     {"sweep_dark",                cf_bool,        CA_GOD,    CA_PUBLIC,   (int *)&mudconf.sweep_dark,      NULL,               0},
     {"switch_default_all",        cf_bool,        CA_GOD,    CA_PUBLIC,   (int *)&mudconf.switch_df_all,   NULL,               0},
@@ -1930,7 +2062,20 @@ static CONF conftable[] =
     {"def_exit_tx",               cf_int,         CA_WIZARD, CA_PUBLIC,   (int *)&mudconf.def_exit_tx,     NULL,               0},
     {"def_thing_rx",              cf_int,         CA_WIZARD, CA_PUBLIC,   (int *)&mudconf.def_thing_rx,    NULL,               0},
     {"def_thing_tx",              cf_int,         CA_WIZARD, CA_PUBLIC,   (int *)&mudconf.def_thing_tx,    NULL,               0},
-#endif /* REALITY_LVLS */
+#endif // REALITY_LVLS
+
+#ifdef FIRANMUX
+    {"immobile_message",          cf_string,      CA_WIZARD, CA_PUBLIC,   (int *)mudconf.immobile_msg,     NULL,             128},
+    {"sql_server",                cf_string,      CA_STATIC, CA_DISABLED, (int *)mudconf.sql_server,       NULL,             128},
+    {"sql_user",                  cf_string,      CA_STATIC, CA_DISABLED, (int *)mudconf.sql_user,         NULL,             128},
+    {"sql_password",              cf_string,      CA_STATIC, CA_DISABLED, (int *)mudconf.sql_password,     NULL,             128},
+    {"sql_database",              cf_string,      CA_STATIC, CA_DISABLED, (int *)mudconf.sql_database,     NULL,             128},
+#endif // FIRANMUX
+    {"mail_server",               cf_string,      CA_STATIC, CA_DISABLED, (int *)mudconf.mail_server,      NULL,             128},
+    {"mail_ehlo",                 cf_string,      CA_STATIC, CA_DISABLED, (int *)mudconf.mail_ehlo,        NULL,             128},
+    {"mail_sendaddr",             cf_string,      CA_STATIC, CA_DISABLED, (int *)mudconf.mail_sendaddr,    NULL,             128},
+    {"mail_sendname",             cf_string,      CA_STATIC, CA_DISABLED, (int *)mudconf.mail_sendname,    NULL,             128},
+    {"mail_subject",              cf_string,      CA_STATIC, CA_DISABLED, (int *)mudconf.mail_subject,     NULL,             128},
     { NULL,                       NULL,           0,         0,           NULL,                            NULL,               0}
 };
 
@@ -1983,7 +2128,6 @@ CF_HAND(cf_cf_access)
 int cf_set(char *cp, char *ap, dbref player)
 {
     CONF *tp;
-    int i;
     char *buff = 0;
 
     // Search the config parameter table for the command. If we find
@@ -1993,46 +2137,52 @@ int cf_set(char *cp, char *ap, dbref player)
     {
         if (!strcmp(tp->pname, cp))
         {
-            if (  !mudstate.bReadingConfiguration
-               && !check_access(player, tp->flags))
+            int i = -1;
+            if (  (tp->flags & CA_DISABLED) == 0
+               && (  mudstate.bReadingConfiguration
+                  || check_access(player, tp->flags)))
+            {
+                if (!mudstate.bReadingConfiguration)
+                {
+                    buff = alloc_lbuf("cf_set");
+                    mux_strncpy(buff, ap, LBUF_SIZE-1);
+                }
+
+                i = tp->interpreter(tp->loc, ap, tp->pExtra, tp->nExtra, player, cp);
+
+                if (!mudstate.bReadingConfiguration)
+                {
+                    STARTLOG(LOG_CONFIGMODS, "CFG", "UPDAT");
+                    log_name(player);
+                    log_text(" entered config directive: ");
+                    log_text(cp);
+                    log_text(" with args '");
+                    log_text(buff);
+                    log_text("'.  Status: ");
+                    switch (i)
+                    {
+                    case 0:
+                        log_text("Success.");
+                        break;
+
+                    case 1:
+                        log_text("Partial success.");
+                        break;
+
+                    case -1:
+                        log_text("Failure.");
+                        break;
+
+                    default:
+                        log_text("Strange.");
+                    }
+                    ENDLOG;
+                    free_lbuf(buff);
+                }
+            }
+            else  if (!mudstate.bReadingConfiguration)
             {
                 notify(player, NOPERM_MESSAGE);
-                return -1;
-            }
-            if (!mudstate.bReadingConfiguration)
-            {
-                buff = alloc_lbuf("cf_set");
-                strcpy(buff, ap);
-            }
-            i = tp->interpreter(tp->loc, ap, tp->pExtra, tp->nExtra, player, cp);
-            if (!mudstate.bReadingConfiguration)
-            {
-                STARTLOG(LOG_CONFIGMODS, "CFG", "UPDAT");
-                log_name(player);
-                log_text(" entered config directive: ");
-                log_text(cp);
-                log_text(" with args '");
-                log_text(buff);
-                log_text("'.  Status: ");
-                switch (i)
-                {
-                case 0:
-                    log_text("Success.");
-                    break;
-
-                case 1:
-                    log_text("Partial success.");
-                    break;
-
-                case -1:
-                    log_text("Failure.");
-                    break;
-
-                default:
-                    log_text("Strange.");
-                }
-                ENDLOG;
-                free_lbuf(buff);
             }
             return i;
         }
@@ -2048,24 +2198,31 @@ int cf_set(char *cp, char *ap, dbref player)
 //
 void ValidateConfigurationDbrefs(void)
 {
-    static dbref *Table[] =
+    static struct
     {
-        &mudconf.default_home,
-        &mudconf.guest_char,
-        &mudconf.guest_nuker,
-        &mudconf.master_room,
-        &mudconf.start_home,
-        &mudconf.start_room,
-        0
+        dbref *ploc;
+        dbref dflt;
+    } Table[] =
+    {
+        { &mudconf.default_home,     NOTHING },
+        { &mudconf.global_error_obj, NOTHING },
+        { &mudconf.guest_char,       NOTHING },
+        { &mudconf.guest_nuker,      GOD     },
+        { &mudconf.hook_obj,         NOTHING },
+        { &mudconf.master_room,      NOTHING },
+        { &mudconf.start_home,       NOTHING },
+        { &mudconf.start_room,       0       },
+        { &mudconf.toad_recipient,   GOD     },
+        { NULL,                      NOTHING }
     };
 
-    for (int i = 0; Table[i]; i++)
+    for (int i = 0; NULL != Table[i].ploc; i++)
     {
-        if (*Table[i] != NOTHING)
+        if (*Table[i].ploc != Table[i].dflt)
         {
-            if (*Table[i] < 0 || mudstate.db_top <= *Table[i])
+            if (!Good_obj(*Table[i].ploc))
             {
-                *Table[i] = NOTHING;
+                *Table[i].ploc = Table[i].dflt;
             }
         }
     }
@@ -2104,7 +2261,7 @@ void do_admin
 static struct
 {
     char **pFilename;
-    char *pSuffix;
+    const char *pSuffix;
 } DefaultSuffixes[]
 =
 {
@@ -2120,12 +2277,12 @@ int cf_read(void)
     int retval;
 
     mudstate.bReadingConfiguration = true;
-    retval = cf_include(NULL, mudconf.config_file, (void *)0, 0, 0, "init");
+    retval = cf_include(NULL, mudconf.config_file, (void *)0, 0, 0, (char *)"init");
     mudstate.bReadingConfiguration = false;
 
     // Fill in missing DB file names.
     //
-    unsigned int nInDB = strlen(mudconf.indb);
+    size_t nInDB = strlen(mudconf.indb);
     for (int i = 0; DefaultSuffixes[i].pFilename; i++)
     {
         char **p = DefaultSuffixes[i].pFilename;
@@ -2134,8 +2291,8 @@ int cf_read(void)
             // The filename is an empty string so we should construct
             // a default filename.
             //
-            char *pSuffix = DefaultSuffixes[i].pSuffix;
-            int nSuffix = strlen(pSuffix);
+            const char *pSuffix = DefaultSuffixes[i].pSuffix;
+            size_t nSuffix = strlen(pSuffix);
             char *buff = (char *)MEMALLOC(nInDB + nSuffix + 1);
             ISOUTOFMEMORY(buff);
             memcpy(buff, mudconf.indb, nInDB);
@@ -2160,7 +2317,7 @@ void list_cf_access(dbref player)
     {
         if (God(player) || check_access(player, tp->flags))
         {
-            sprintf(buff, "%s:", tp->pname);
+            mux_sprintf(buff, MBUF_SIZE, "%s:", tp->pname);
             listset_nametab(player, access_nametab, tp->flags, buff, true);
         }
     }
