@@ -2,7 +2,7 @@
 // Multiguest code rewritten by Matthew J. Leavitt (zenty).
 // Idea for @list guest from Ashen-Shugar and the great team of RhostMUSH
 //
-// $Id: mguests.cpp,v 1.17 2006/01/31 00:17:26 sdennis Exp $
+// $Id: mguests.cpp 2734 2007-10-28 23:02:55Z brazilofmux $
 //
 
 #include "copyright.h"
@@ -147,7 +147,7 @@ const char *CGuests::Create(DESC *d)
         {
             // Lets try to grab our own name, if we don't have it.
             //
-            sprintf(name, "%s%d", mudconf.guest_prefix, i+1);
+            mux_sprintf(name, sizeof(name), "%s%d", mudconf.guest_prefix, i+1);
             dbref j = lookup_player(GOD, name, false);
             if (j == NOTHING)
             {
@@ -163,14 +163,25 @@ const char *CGuests::Create(DESC *d)
                 AddToGuestChannel(guest_player);
             }
 
-            // Reset the flags back to the default.
+            // Copy flags from guest prototype.
             //
-            db[guest_player].fs = mudconf.player_flags;
+            db[guest_player].fs = db[mudconf.guest_char].fs;
 
-            // Add the type and remove wizard.
+            // Strip flags, enforce PLAYER type.
             //
-            db[guest_player].fs.word[FLAG_WORD1] |= TYPE_PLAYER;
-            db[guest_player].fs.word[FLAG_WORD1] &= ~WIZARD;
+            FLAG aClearFlags[3];
+            FLAG aSetFlags[3];
+
+            aClearFlags[FLAG_WORD1] = WIZARD
+                                    | TYPE_MASK
+                                    | mudconf.stripped_flags.word[FLAG_WORD1];
+            aClearFlags[FLAG_WORD2] = mudconf.stripped_flags.word[FLAG_WORD2];
+            aClearFlags[FLAG_WORD3] = mudconf.stripped_flags.word[FLAG_WORD3];
+            aSetFlags[FLAG_WORD1] = TYPE_PLAYER;
+            aSetFlags[FLAG_WORD2] = 0;
+            aSetFlags[FLAG_WORD3] = 0;
+
+            SetClearFlags(guest_player, aClearFlags, aSetFlags);
 
             // Make sure they're a guest.
             //
@@ -284,7 +295,7 @@ dbref CGuests::MakeGuestChar(void)
     bool bFound = false;
     for (i = 0; i < mudconf.number_guests;i++)
     {
-        sprintf(name, "%s%d", mudconf.guest_prefix, i + 1);
+        mux_sprintf(name, sizeof(name), "%s%d", mudconf.guest_prefix, i + 1);
         player = lookup_player(GOD, name, false);
         if (player == NOTHING)
         {
@@ -300,7 +311,7 @@ dbref CGuests::MakeGuestChar(void)
     // Make the player.
     //
     const char *pmsg;
-    player = create_player(name, GUEST_PASSWORD, mudconf.guest_nuker, false, &pmsg);
+    player = create_player(name, (char *)GUEST_PASSWORD, mudconf.guest_nuker, false, &pmsg);
 
     // No Player Created?? Return error.
     //
@@ -316,7 +327,24 @@ dbref CGuests::MakeGuestChar(void)
     AddToGuestChannel(player);
     s_Guest(player);
     move_object(player, mudconf.start_room);
-    db[player].fs.word[FLAG_WORD1] &= ~WIZARD;
+
+    // Copy flags from guest prototype and restore the player type.
+    //
+    FLAGSET f = db[mudconf.guest_char].fs;
+    f.word[FLAG_WORD1] |= TYPE_PLAYER;
+    db[player].fs = f;
+
+    // Strip flags.
+    //
+    FLAG aClearFlags[3];
+
+    aClearFlags[FLAG_WORD1] = WIZARD
+                            | mudconf.stripped_flags.word[FLAG_WORD1];
+    aClearFlags[FLAG_WORD2] = mudconf.stripped_flags.word[FLAG_WORD2];
+    aClearFlags[FLAG_WORD3] = mudconf.stripped_flags.word[FLAG_WORD3];
+
+    SetClearFlags(player, aClearFlags, NULL);
+
     s_Pennies(player, Pennies(mudconf.guest_char));
     s_Zone(player, Zone(mudconf.guest_char));
     s_Parent(player, Parent(mudconf.guest_char));
@@ -327,8 +355,8 @@ dbref CGuests::MakeGuestChar(void)
 
     // Lock em!
     //
-    do_lock(player, player, player, A_LOCK, 2, tprintf("#%d", player), "=me");
-    do_lock(player, player, player, A_LENTER, 2, tprintf("#%d", player), "=me");
+    do_lock(player, player, player, A_LOCK, 2, tprintf("#%d", player), (char *)"=me");
+    do_lock(player, player, player, A_LENTER, 2, tprintf("#%d", player), (char *)"=me");
 
     // return em!
     //
@@ -407,7 +435,7 @@ void CGuests::ListAll(dbref player)
         dbref aowner;
         int aflags;
         atr_get_str(LastSite, Guests[i], A_LASTSITE, &aowner, &aflags);
-        sprintf(buff, "%sGuest %-3d: %-15s #%-5d %-10s %s",
+        mux_sprintf(buff, LBUF_SIZE, "%sGuest %-3d: %-15s #%-5d %-10s %s",
                 (i<mudconf.min_guests ? "*" : " "),
                 i, Name(Guests[i]), Guests[i],
                 (Connected(Guests[i]) ? "Online" : "NotOnline"),
