@@ -1,6 +1,6 @@
 // mudconf.h
 //
-// $Id: mudconf.h,v 1.35 2006/05/18 18:43:44 sdennis Exp $
+// $Id: mudconf.h 2734 2007-10-28 23:02:55Z brazilofmux $
 //
 
 #ifndef __CONF_H
@@ -141,7 +141,7 @@ struct confdata
     RLEVEL  def_exit_tx;        /* Default exit TX level */
     RLEVEL  def_thing_rx;       /* Default thing RX level */
     RLEVEL  def_thing_tx;       /* Default thing TX level */
-#endif /* REALITY_LVLS */
+#endif // REALITY_LVLS
     int     ntfy_nest_lim;      /* Max nesting of notifys */
     int     number_guests;      // number of guest characters allowed.
     int     opencost;           /* cost of @open command */
@@ -172,7 +172,9 @@ struct confdata
     int     waitcost;           /* cost of @wait (refunded when finishes) */
     int     wild_invk_lim;      // Max Regular Expression function calls.
     int     zone_nest_lim;      /* Max nesting of zones */
-    int     restrict_home;	// Special condition to restrict 'home' command
+    int     restrict_home;      // Special condition to restrict 'home' command
+    int     float_precision;    // Maximum precision of float-to-string conversion.
+    int     lbuf_size;          // LBUF_SIZE accessible to softcode.
 
     unsigned int    max_cache_size; /* Max size of attribute cache */
     unsigned int    site_chars; // where to truncate site name.
@@ -187,10 +189,26 @@ struct confdata
     char    one_coin[32];       /* name of one coin (ie. "penny") */
     char    public_channel[32]; /* Name of public channel */
     char    public_channel_alias[32]; /* Name of public channel alias */
-    char    dump_msg[128];      /* Message displayed when @dump-ing */
+    char    dump_msg[256];      /* Message displayed when @dump-ing */
     char    fixed_home_msg[128];    /* Message displayed when going home and FIXED */
     char    fixed_tel_msg[128]; /* Message displayed when teleporting and FIXED */
-    char    postdump_msg[128];  /* Message displayed after @dump-ing */
+    char    postdump_msg[256];  /* Message displayed after @dump-ing */
+#ifdef FIRANMUX
+    char    immobile_msg[128];  /* Message displayed to immobile players */
+#endif // FIRANMUX
+#ifdef FIRANMUX
+    char    sql_server[128];
+    char    sql_user[128];
+    char    sql_password[128];
+    char    sql_database[128];
+#endif // FIRANMUX
+
+    char    mail_server[128];
+    char    mail_ehlo[128];
+    char    mail_sendaddr[128];
+    char    mail_sendname[128];
+    char    mail_subject[128];
+
     char    downmotd_msg[GBUF_SIZE];    /* Settable 'logins disabled' message */
     char    fullmotd_msg[GBUF_SIZE];    /* Settable 'Too many players' message */
     char    motd_msg[GBUF_SIZE];    /* Wizard-settable login message */
@@ -209,6 +227,7 @@ struct confdata
     char    *game_pag;          /* use this game CHashFile PAG file if we need one */
     char    *guest_file;        /* display if guest connects */
     char    *indb;              /* database file name */
+    char    *log_dir;           /* directory for logging from the cmd line */
     char    *mail_db;           /* name of the @mail database */
     char    *motd_file;         /* display this file on login */
     char    *outdb;             /* checkpoint the database to here */
@@ -218,7 +237,7 @@ struct confdata
     char    *status_file;       /* Where to write arg to @shutdown */
     char    *uncompress;        /* program to run to uncompress */
     char    *wizmotd_file;      /* display this file on login to wizards */
-    char    *pid_file;          // file for communicating process id back to ./Startmux
+    const char *pid_file;       // file for communicating process id back to ./Startmux
     unsigned char    markdata[8];  /* Masks for marking/unmarking */
     CLinearTimeDelta rpt_cmdsecs;  /* Reporting Threshhold for time taken by command */
     CLinearTimeDelta max_cmdsecs;  /* Upper Limit for real time taken by command */
@@ -230,6 +249,7 @@ struct confdata
     FLAGSET robot_flags;        /* Flags robots start with */
     FLAGSET room_flags;         /* Flags rooms start with */
     FLAGSET thing_flags;        /* Flags things start with */
+    FLAGSET stripped_flags;     // Flags stripped by @chown, @chownall, and @clone.
 
     ArtRuleset* art_rules;      /* Rulesets for defining exceptions. */
 };
@@ -290,7 +310,7 @@ typedef struct forward_list FWDLIST;
 struct forward_list
 {
     int count;
-    int data[1000];
+    dbref *data;
 };
 
 #define MAX_ITEXT 100
@@ -350,7 +370,6 @@ struct statedata
     int     mstat_isrss[2];     /* Summed private stack size */
     int     mstat_ixrss[2];     /* Summed shared size */
     int     mstat_secs[2];      /* Time of samples */
-    int     glob_reg_len[MAX_GLOBAL_REGS];  /* Length of strs */
     int     inum[MAX_ITEXT];    // Number of iter(). Equivalent to #@.
     int     *guest_free;        /* Table to keep track of free guests */
     size_t  mod_alist_len;      /* Length of mod_alist */
@@ -359,15 +378,15 @@ struct statedata
     char    short_ver[64];      /* Short version number (for INFO) */
     char    doing_hdr[SIZEOF_DOING_STRING];  /* Doing column header in the WHO display */
     char    version[128];       /* MUX version string */
-    char    *curr_cmd;          /* The current command */
-    char    *debug_cmd;         // The command we are executing (if any).
+    const char *curr_cmd;       // The current command.
+    const char *debug_cmd;      // The command we are executing (if any).
     char    *mod_alist;         /* Attribute list for modifying */
     char    *pout;              /* The output of the pipe used in %| */
     char    *poutbufc;          /* Buffer position for poutnew */
     char    *poutnew;           /* The output being build by the current command */
-    char    *global_regs[MAX_GLOBAL_REGS];  /* Global registers */
     char    *itext[MAX_ITEXT];  // Text of iter(). Equivalent to ##.
 
+    reg_ref *global_regs[MAX_GLOBAL_REGS];  /* Global registers */
     ALIST   iter_alist;         /* Attribute list for iterations */
     BADNAME *badname_head;      /* List of disallowed names */
     HELP_DESC *aHelpDesc;       // Table of help files hashes.
@@ -384,7 +403,9 @@ struct statedata
     CLinearTimeAbsolute start_time;     /* When was MUX started */
     CLinearTimeAbsolute tThrottleExpired; // How much time is left in this hour of throttling.
 
+#if !defined(MEMORY_BASED)
     CHashTable acache_htab;     // Attribute Cache
+#endif // MEMORY_BASED
     CHashTable attr_name_htab;  /* Attribute names hashtable */
     CHashTable channel_htab;    /* Channels hashtable */
     CHashTable command_htab;    /* Commands hashtable */
