@@ -1,10 +1,6 @@
 // muxcli.cpp
 //
-// $Id: muxcli.cpp,v 1.4 2004/06/10 15:39:34 sdennis Exp $
-//
-// MUX 2.4
-// Copyright (C) 1998 through 2004 Solid Vertical Domains, Ltd. All
-// rights not explicitly given are reserved.
+// $Id: muxcli.cpp 2475 2007-09-15 16:18:35Z brazilofmux $
 //
 #include "copyright.h"
 #include <string.h>
@@ -96,14 +92,14 @@ void CLI_Process
             continue;
         }
 
-        char *p = pArgv+iType;
+        const char *p = pArgv+iType;
 
         if (iType == 2)
         {
             // We have a long option.
             //
             char *pEqual = strchr(p, '=');
-            int nLen;
+            size_t nLen;
             if (pEqual)
             {
                 nLen = pEqual - p;
