@@ -1,6 +1,6 @@
 // speech.cpp -- Commands which involve speaking.
 //
-// $Id: speech.cpp,v 1.22 2006/01/07 08:10:56 sdennis Exp $
+// $Id: speech.cpp 2734 2007-10-28 23:02:55Z brazilofmux $
 //
 
 #include "copyright.h"
@@ -37,7 +37,8 @@ char *modSpeech(dbref player, char *message, bool bWhich, char *command)
     args[0] = message;
     args[1] = command;
     mux_exec(new_message, &t_ptr, player, player, player,
-        EV_FCHECK | EV_EVAL | EV_TOP, &mod, args, 2);
+        AttrTrace(aflags, EV_FCHECK|EV_EVAL|EV_TOP), &mod, args, 2);
+    *t_ptr = '\0';
     free_lbuf(mod_orig);
     return new_message;
 }
@@ -133,7 +134,7 @@ static const char *announce_msg = "Announcement: ";
 static const char *broadcast_msg = "Broadcast: ";
 static const char *admin_msg = "Admin: ";
 
-void do_think(dbref executor, dbref caller, dbref enactor, int key,
+void do_think(dbref executor, dbref caller, dbref enactor, int eval, int key,
     char *message)
 {
     UNUSED_PARAMETER(key);
@@ -142,23 +143,24 @@ void do_think(dbref executor, dbref caller, dbref enactor, int key,
 
     buf = bp = alloc_lbuf("do_think");
     str = message;
-    mux_exec(buf, &bp, executor, caller, enactor, EV_FCHECK | EV_EVAL | EV_TOP,
-             &str, (char **)NULL, 0);
+    mux_exec(buf, &bp, executor, caller, enactor, eval|EV_FCHECK|EV_EVAL|EV_TOP,
+         &str, NULL, 0);
     *bp = '\0';
     notify(executor, buf);
     free_lbuf(buf);
 }
 
-void do_say(dbref executor, dbref caller, dbref enactor, int key, char *message)
+void do_say(dbref executor, dbref caller, dbref enactor, int eval, int key, char *message)
 {
     UNUSED_PARAMETER(caller);
     UNUSED_PARAMETER(enactor);
+    UNUSED_PARAMETER(eval);
 
     // Make sure speaker is somewhere if speaking in a place
     //
     dbref loc = where_is(executor);
     if ( !(  Good_obj(loc)
-            & sp_ok(executor)))
+          && sp_ok(executor)))
     {
         return;
     }
@@ -209,18 +211,18 @@ void do_say(dbref executor, dbref caller, dbref enactor, int key, char *message)
         }
     }
 
-    char *command = "";
+    char *command = (char *)"";
     if (SAY_SAY == key)
     {
-        command = "say";
+        command = (char *)"say";
     }
     else if (SAY_POSE == key || SAY_POSE_NOSPC == key)
     {
-        command = "pose";
+        command = (char *)"pose";
     }
     else if (SAY_EMIT == key)
     {
-        command = "@emit";
+        command = (char *)"@emit";
     }
 
     // Parse speechmod if present.
@@ -342,11 +344,12 @@ void do_say(dbref executor, dbref caller, dbref enactor, int key, char *message)
 }
 
 
-void do_shout(dbref executor, dbref caller, dbref enactor, int key,
+void do_shout(dbref executor, dbref caller, dbref enactor, int eval, int key,
     char *message)
 {
     UNUSED_PARAMETER(caller);
     UNUSED_PARAMETER(enactor);
+    UNUSED_PARAMETER(eval);
 
     char *p;
     char *buf2, *bp;
@@ -355,7 +358,7 @@ void do_shout(dbref executor, dbref caller, dbref enactor, int key,
 
     // Parse speechmod if present.
     //
-    char *messageNew = modSpeech(executor, message, true, "@wall");
+    char *messageNew = modSpeech(executor, message, true, (char *)"@wall");
     if (messageNew)
     {
         message = messageNew;
@@ -560,8 +563,8 @@ static void page_return(dbref player, dbref target, const char *tag,
         str2 = bp = alloc_lbuf("page_return");
         buf = str;
         mux_exec(str2, &bp, target, player, player,
-                 EV_FCHECK | EV_EVAL | EV_TOP | EV_NO_LOCATION, &buf,
-                 (char **)NULL, 0);
+             AttrTrace(aflags, EV_FCHECK|EV_EVAL|EV_TOP|EV_NO_LOCATION),
+             &buf, NULL, 0);
         *bp = '\0';
         if (*str2)
         {
@@ -934,7 +937,7 @@ void do_page
         pageMode = 0;
     }
 
-    char *newMessage = modSpeech(executor, pMessage, true, "page");
+    char *newMessage = modSpeech(executor, pMessage, true, (char *)"page");
     if (newMessage)
     {
         pMessage = newMessage;
@@ -1027,13 +1030,13 @@ void do_page
 
 static void whisper_pose(dbref player, dbref target, char *message, bool bSpace)
 {
-    char *newMessage = modSpeech(player, message, true, "whisper");
+    char *newMessage = modSpeech(player, message, true, (char *)"whisper");
     if (newMessage)
     {
         message = newMessage;
     }
     char *buff = alloc_lbuf("do_pemit.whisper.pose");
-    strcpy(buff, Moniker(player));
+    mux_strncpy(buff, Moniker(player), LBUF_SIZE-1);
     notify(player, tprintf("%s senses \"%s%s%s\"", Moniker(target), buff,
         bSpace ? " " : "", message));
     notify_with_cause(target, player, tprintf("You sense %s%s%s", buff,
@@ -1201,7 +1204,7 @@ void do_pemit_single
                 message++;
 
             default:
-                newMessage = modSpeech(player, message, true, "whisper");
+                newMessage = modSpeech(player, message, true, (char *)"whisper");
                 if (newMessage)
                 {
                     message = newMessage;
@@ -1234,7 +1237,7 @@ void do_pemit_single
             break;
 
         case PEMIT_FSAY:
-            newMessage = modSpeech(target, message, true, "@fsay");
+            newMessage = modSpeech(target, message, true, (char *)"@fsay");
             if (newMessage)
             {
                 message = newMessage;
@@ -1242,7 +1245,7 @@ void do_pemit_single
             notify(target, tprintf("You say, \"%s\"", message));
             if (loc != NOTHING)
             {
-                saystring = modSpeech(target, message, false, "@fsay");
+                saystring = modSpeech(target, message, false, (char *)"@fsay");
                 if (saystring)
                 {
                     p = tprintf("%s %s \"%s\"", Moniker(target),
@@ -1267,7 +1270,7 @@ void do_pemit_single
             break;
 
         case PEMIT_FPOSE:
-            newMessage = modSpeech(target, message, true, "@fpose");
+            newMessage = modSpeech(target, message, true, (char *)"@fpose");
             if (newMessage)
             {
                 message = newMessage;
@@ -1281,7 +1284,7 @@ void do_pemit_single
             break;
 
         case PEMIT_FPOSE_NS:
-            newMessage = modSpeech(target, message, true, "@fpose");
+            newMessage = modSpeech(target, message, true, (char *)"@fpose");
             if (newMessage)
             {
                 message = newMessage;
