@@ -1,10 +1,6 @@
 // svdhash.cpp -- CHashPage, CHashFile, CHashTable modules.
 //
-// $Id: svdhash.cpp,v 1.44 2006/08/07 05:49:48 sdennis Exp $
-//
-// MUX 2.4
-// Copyright (C) 1998 through 2004 Solid Vertical Domains, Ltd. All
-// rights not explicitly given are reserved.
+// $Id: svdhash.cpp 2475 2007-09-15 16:18:35Z brazilofmux $
 //
 #include "copyright.h"
 #include "autoconf.h"
@@ -98,7 +94,7 @@ UINT32 CRC32_ProcessBuffer
 (
     UINT32         ulCrc,
     const void    *arg_pBuffer,
-    unsigned int   nBuffer
+    size_t         nBuffer
 )
 {
     UINT8 *pBuffer = (UINT8 *)arg_pBuffer;
@@ -314,19 +310,24 @@ static void ChoosePrimes(int TableSize, HP_HEAPOFFSET HashPrimes[16])
         int Lower = Primes[0];
         for (int jPrime = 0; Primes[jPrime] != 0; jPrime++)
         {
-            if (jPrime != 0 && TableSize % Primes[jPrime] == 0) continue;
+            if (  jPrime != 0
+               && TableSize % Primes[jPrime] == 0)
+            {
+                continue;
+            }
             int Upper = Primes[jPrime];
-            if (Lower <= iZone && iZone <= Upper)
+            if (  Lower <= iZone
+               && iZone <= Upper)
             {
                 // Choose the closest lower prime number.
                 //
                 if (iZone - Lower <= Upper - iZone)
                 {
-                    HashPrimes[iPrime++] = Lower;
+                    HashPrimes[iPrime++] = static_cast<HP_HEAPOFFSET>(Lower);
                 }
                 else
                 {
-                    HashPrimes[iPrime++] = Upper;
+                    HashPrimes[iPrime++] = static_cast<HP_HEAPOFFSET>(Upper);
                 }
                 break;
             }
@@ -338,7 +339,7 @@ static void ChoosePrimes(int TableSize, HP_HEAPOFFSET HashPrimes[16])
     //
     for (iPrime = 0; iPrime < 16; iPrime += 2)
     {
-        HashPrimes[iPrime] = TableSize-HashPrimes[iPrime];
+        HashPrimes[iPrime] = static_cast<HP_HEAPOFFSET>(TableSize-HashPrimes[iPrime]);
     }
 
     // Shuffle the set of primes to reduce correlation with bits in
@@ -408,12 +409,11 @@ void CHashPage::GetStats
     HP_HEAPLENGTH nExtra,
     int *pnRecords,
     HP_HEAPLENGTH *pnAllocatedSize,
-    int *pnGoodDirSize
+    UINT32        *pnGoodDirSize
 )
 {
-    unsigned nSize = 0;
-    unsigned nCount = 0;
-    unsigned nGoodDirSize = 100;
+    UINT32  nSize  = 0;
+    UINT32  nCount = 0;
 
     // Count and measure all the records in this page.
     //
@@ -434,16 +434,18 @@ void CHashPage::GetStats
         }
     }
     *pnRecords = nCount;
-    *pnAllocatedSize = nSize;
+    *pnAllocatedSize = static_cast<HP_HEAPLENGTH>(nSize);
 
     // If we have records to talk about, or even if we are trying to reserve
     // space, then do the math.
     //
+    UINT32 nGoodDirSize = 100;
     if (  nExtra != 0
        || nCount != 0)
     {
-        UINT32 nSpace = (UINT32)( ((unsigned char *)m_pTrailer)
-                                - ((unsigned char *)m_pDirectory));
+        size_t nSpaceTmp   = ((unsigned char *)m_pTrailer) - ((unsigned char *)m_pDirectory);
+        mux_assert(nSpaceTmp <= UINT32_MAX_VALUE);
+        UINT32 nSpace      = static_cast<UINT32>(nSpaceTmp);
         UINT32 nMinDirSize = nCount;
         UINT32 nMaxDirSize = (nSpace - nSize)/sizeof(HP_HEAPOFFSET);
 
@@ -462,7 +464,7 @@ void CHashPage::GetStats
 #define FILL_FACTOR 1
         UINT32 nAverageSize = (nSize + nCount/2)/nCount;
         UINT32 nHeapGoal = (nSpace * nAverageSize)/(nAverageSize + sizeof(HP_HEAPOFFSET) + FILL_FACTOR);
-        nGoodDirSize = (UINT32)((nSpace - nHeapGoal + sizeof(HP_HEAPOFFSET)/2)/sizeof(HP_HEAPOFFSET));
+        nGoodDirSize = (nSpace - nHeapGoal + sizeof(HP_HEAPOFFSET)/2)/sizeof(HP_HEAPOFFSET);
         if (nGoodDirSize < nMinDirSize)
         {
             nGoodDirSize = nMinDirSize;
@@ -483,14 +485,14 @@ void CHashPage::SetFixedPointers(void)
     m_pTrailer = (HP_PTRAILER)(m_pPage + m_nPageSize - sizeof(HP_TRAILER));
 }
 
-void CHashPage::Empty(HP_DIRINDEX arg_nDepth, UINT32 arg_nHashGroup, HP_DIRINDEX arg_nDirSize)
+void CHashPage::Empty(UINT32 arg_nDepth, UINT32 arg_nHashGroup, UINT32 arg_nDirSize)
 {
     memset(m_pPage, 0, m_nPageSize);
 
     SetFixedPointers();
 
-    m_pHeader->m_nDepth = arg_nDepth;
-    m_pHeader->m_nDirSize = arg_nDirSize;
+    m_pHeader->m_nDepth = static_cast<HP_DIRINDEX>(arg_nDepth);
+    m_pHeader->m_nDirSize = static_cast<HP_DIRINDEX>(arg_nDirSize);
     m_pHeader->m_nHashGroup = arg_nHashGroup;
     m_pHeader->m_nTotalInsert = 0;
     m_pHeader->m_nDirEmptyLeft = arg_nDirSize;  // Number of entries marked HP_DIR_EMPTY.
@@ -536,9 +538,14 @@ bool CHashPage::Validate(void)
 //
 bool CHashPage::ValidateAllocatedBlock(UINT32 iDir)
 {
-    if (iDir >= m_pHeader->m_nDirSize) return false;
-    if (m_pDirectory[iDir] >= HP_DIR_DELETED)
+    if (iDir >= m_pHeader->m_nDirSize)
+    {
         return false;
+    }
+    if (m_pDirectory[iDir] >= HP_DIR_DELETED)
+    {
+        return false;
+    }
 
     // Use directory entry to go find heap node. The record itself follows.
     //
@@ -652,7 +659,7 @@ int CHashPage::Insert(HP_HEAPLENGTH nRecord, UINT32 nHash, void *pRecord)
 #ifdef HP_PROTECTION
         // First, is this page dealing with keys like this at all?
         //
-        HP_DIRINDEX nDepth = m_pHeader->m_nDepth;
+        UINT32 nDepth = m_pHeader->m_nDepth;
         if ((nHash & anGroupMask[nDepth]) != m_pHeader->m_nHashGroup)
         {
             Log.WriteString("CHashPage::Insert - Inserting into the wrong page." ENDLINE);
@@ -662,8 +669,8 @@ int CHashPage::Insert(HP_HEAPLENGTH nRecord, UINT32 nHash, void *pRecord)
 
         // Where do we begin our first probe?
         //
-        int di   = m_pHeader->m_Primes[nHash & 15];
-        int iDir = (nHash >> 4) % (m_pHeader->m_nDirSize);
+        UINT32 di   = m_pHeader->m_Primes[nHash & 15];
+        UINT32 iDir = (nHash >> 4) % (m_pHeader->m_nDirSize);
         m_nProbesLeft = m_pHeader->m_nDirSize;
         while (m_nProbesLeft-- && (m_pDirectory[iDir] < HP_DIR_DELETED))
         {
@@ -706,23 +713,25 @@ int CHashPage::Insert(HP_HEAPLENGTH nRecord, UINT32 nHash, void *pRecord)
 //        iDir == HP_DIR_EMPTY to interate through all the records with the
 //        desired hash key.
 //
-HP_DIRINDEX CHashPage::FindFirstKey(UINT32 nHash, unsigned int *numchecks)
+UINT32 CHashPage::FindFirstKey(UINT32 nHash, unsigned int *numchecks)
 {
 #ifdef HP_PROTECTION
     // First, is this page dealing with keys like this at all?
     //
-    HP_DIRINDEX nDepth = m_pHeader->m_nDepth;
+    UINT32 nDepth = m_pHeader->m_nDepth;
     if ((nHash & anGroupMask[nDepth]) != m_pHeader->m_nHashGroup)
+    {
         return HP_DIR_EMPTY;
+    }
 #endif // HP_PROTECTION
 
-    const int nDirSize = m_pHeader->m_nDirSize;
+    const UINT32 nDirSize = m_pHeader->m_nDirSize;
 
     // Where do we begin our first probe?
     //
-    int iDir = (nHash >> 4) % nDirSize;
-    int sOffset = m_pDirectory[iDir];
-    if ((unsigned int)sOffset < HP_DIR_DELETED)
+    UINT32 iDir = (nHash >> 4) % nDirSize;
+    UINT32 sOffset = m_pDirectory[iDir];
+    if (sOffset < HP_DIR_DELETED)
     {
         HP_PHEAPNODE pNode = (HP_PHEAPNODE)(m_pHeapStart + sOffset);
         if (pNode->u.s.nHash == nHash)
@@ -743,7 +752,7 @@ HP_DIRINDEX CHashPage::FindFirstKey(UINT32 nHash, unsigned int *numchecks)
     // || pNode->u.s.nHash != nHash
 
     m_nProbesLeft = nDirSize - 1;
-    int di = m_pHeader->m_Primes[nHash & 15];
+    UINT32 di = m_pHeader->m_Primes[nHash & 15];
 
     iDir += di;
     if (iDir >= nDirSize)
@@ -782,24 +791,26 @@ HP_DIRINDEX CHashPage::FindFirstKey(UINT32 nHash, unsigned int *numchecks)
 //        directory index or HP_DIR_EMPTY if no hash keys are found.
 //
 //
-HP_DIRINDEX CHashPage::FindNextKey(HP_DIRINDEX iDir, UINT32 nHash, unsigned int *numchecks)
+UINT32 CHashPage::FindNextKey(UINT32 iDir, UINT32 nHash, unsigned int *numchecks)
 {
     *numchecks = 0;
 
 #ifdef HP_PROTECTION
     // First, is this page dealing with keys like this at all?
     //
-    HP_DIRINDEX nDepth = m_pHeader->m_nDepth;
+    UINT32 nDepth = m_pHeader->m_nDepth;
     if ((nHash & anGroupMask[nDepth]) != m_pHeader->m_nHashGroup)
+    {
         return HP_DIR_EMPTY;
+    }
 #endif // HP_PROTECTION
 
-    int nDirSize = m_pHeader->m_nDirSize;
+    UINT32 nDirSize = m_pHeader->m_nDirSize;
 
     // Where do we begin our first probe? If this is the first call, i will be HP_DIR_EMPTY.
     // On calls after that, it will be what we returned on the previous call.
     //
-    int di = m_pHeader->m_Primes[nHash & 15];
+    UINT32 di = m_pHeader->m_Primes[nHash & 15];
     iDir += di;
     if (iDir >= nDirSize)
     {
@@ -814,7 +825,10 @@ HP_DIRINDEX CHashPage::FindNextKey(HP_DIRINDEX iDir, UINT32 nHash, unsigned int
             if (m_pDirectory[iDir] < HP_DIR_DELETED) // ValidateAllocatedBlock(iDir))
             {
                 HP_PHEAPNODE pNode = (HP_PHEAPNODE)(m_pHeapStart + m_pDirectory[iDir]);
-                if (pNode->u.s.nHash == nHash) return iDir;
+                if (pNode->u.s.nHash == nHash)
+                {
+                    return iDir;
+                }
             }
         }
         iDir += di;
@@ -829,7 +843,7 @@ HP_DIRINDEX CHashPage::FindNextKey(HP_DIRINDEX iDir, UINT32 nHash, unsigned int
 // HeapAlloc - Return true if there was enough room to copy the record into the heap, otherwise,
 //             it returns false.
 //
-bool CHashPage::HeapAlloc(HP_DIRINDEX iDir, HP_HEAPLENGTH nRecord, UINT32 nHash, void *pRecord)
+bool CHashPage::HeapAlloc(UINT32 iDir, HP_HEAPLENGTH nRecord, UINT32 nHash, void *pRecord)
 {
     //ValidateFreeList();
     if (m_pDirectory[iDir] < HP_DIR_DELETED)
@@ -866,13 +880,13 @@ bool CHashPage::HeapAlloc(HP_DIRINDEX iDir, HP_HEAPLENGTH nRecord, UINT32 nHash,
             //
             // Do we cut it into two blocks or take the whole thing?
             //
-            HP_HEAPLENGTH nNewBlockSize = pNode->nBlockSize - nRequired;
+            UINT32 nNewBlockSize = pNode->nBlockSize - nRequired;
             if (nNewBlockSize >= EXPAND_TO_BOUNDARY(HP_MIN_HEAP_ALLOC+1))
             {
                 // There is enough for leftovers, split it.
                 //
                 HP_PHEAPNODE pNewNode = (HP_PHEAPNODE)(pBlockStart + nRequired);
-                pNewNode->nBlockSize = nNewBlockSize;
+                pNewNode->nBlockSize = static_cast<HP_HEAPLENGTH>(nNewBlockSize);
                 pNewNode->u.oNext = pNode->u.oNext;
 
                 // Update current node.
@@ -883,7 +897,7 @@ bool CHashPage::HeapAlloc(HP_DIRINDEX iDir, HP_HEAPLENGTH nRecord, UINT32 nHash,
 
                 // Update Free list pointer.
                 //
-                *poPrev += nRequired;
+                *poPrev = static_cast<HP_HEAPLENGTH>(*poPrev + nRequired);
             }
             else
             {
@@ -910,7 +924,7 @@ bool CHashPage::HeapAlloc(HP_DIRINDEX iDir, HP_HEAPLENGTH nRecord, UINT32 nHash,
 // HeapFree - Returns to the heap the space for the record associated with iDir. It
 //            always succeeds even if there wasn't a record there to delete.
 //
-void CHashPage::HeapFree(HP_DIRINDEX iDir)
+void CHashPage::HeapFree(UINT32 iDir)
 {
     //ValidateFreeList();
     if (m_pDirectory[iDir] < HP_DIR_DELETED) // ValidateAllocatedBlock(iDir))
@@ -934,7 +948,7 @@ void CHashPage::HeapFree(HP_DIRINDEX iDir)
     }
 }
 
-void CHashPage::HeapCopy(HP_DIRINDEX iDir, HP_PHEAPLENGTH pnRecord, void *pRecord)
+void CHashPage::HeapCopy(UINT32 iDir, HP_PHEAPLENGTH pnRecord, void *pRecord)
 {
     if (pnRecord == 0 || pRecord == 0) return;
 
@@ -949,7 +963,7 @@ void CHashPage::HeapCopy(HP_DIRINDEX iDir, HP_PHEAPLENGTH pnRecord, void *pRecor
     }
 }
 
-void CHashPage::HeapUpdate(HP_DIRINDEX iDir, HP_HEAPLENGTH nRecord, void *pRecord)
+void CHashPage::HeapUpdate(UINT32 iDir, HP_HEAPLENGTH nRecord, void *pRecord)
 {
     if (nRecord == 0 || pRecord == 0) return;
 
@@ -966,9 +980,9 @@ bool CHashPage::Split(CHashPage &hp0, CHashPage &hp1)
 {
     // Figure out what a good directory size is given the actual records in this page.
     //
-    int   nRecords;
+    int           nRecords;
     HP_HEAPLENGTH nAllocatedSize;
-    int   nGoodDirSize;
+    UINT32        nGoodDirSize;
     GetStats(0, &nRecords, &nAllocatedSize, &nGoodDirSize);
     if (nRecords == 0)
     {
@@ -978,7 +992,7 @@ bool CHashPage::Split(CHashPage &hp0, CHashPage &hp1)
 
     // Initialize that type of HashPage and copy records over.
     //
-    int   nNewDepth = m_pHeader->m_nDepth + 1;
+    UINT32 nNewDepth = m_pHeader->m_nDepth + 1;
     UINT32 nBitMask = 1 << (32-nNewDepth);
     UINT32 nHashGroup0 = m_pHeader->m_nHashGroup & (~nBitMask);
     UINT32 nHashGroup1 = nHashGroup0 | nBitMask;
@@ -1049,6 +1063,8 @@ void CHashPage::GetRange
     nEnd   = nBase | ~ulMask;
 }
 
+#if !defined(MEMORY_BASED)
+
 #ifdef WIN32
 bool CHashPage::WritePage(HANDLE hFile, HF_FILEOFFSET oWhere)
 {
@@ -1110,12 +1126,12 @@ bool CHashPage::WritePage(HANDLE hFile, HF_FILEOFFSET oWhere)
 #ifdef HAVE_PWRITE
         int cc = pwrite(hFile, m_pPage, m_nPageSize, oWhere);
 #else
-        if (lseek(hFile, oWhere, SEEK_SET) == (off_t)-1)
+        if (mux_lseek(hFile, oWhere, SEEK_SET) == (off_t)-1)
         {
             Log.tinyprintf("CHashPage::Write - lseek error %u." ENDLINE, errno);
             continue;
         }
-        int cc = write(hFile, m_pPage, m_nPageSize);
+        int cc = mux_write(hFile, m_pPage, m_nPageSize);
 #endif // HAVE_PWRITE
         if ((int)m_nPageSize != cc)
         {
@@ -1150,12 +1166,12 @@ bool CHashPage::ReadPage(HANDLE hFile, HF_FILEOFFSET oWhere)
 #ifdef HAVE_PREAD
         int cc = pread(hFile, m_pPage, m_nPageSize, oWhere);
 #else
-        if (lseek(hFile, oWhere, SEEK_SET) == (off_t)-1)
+        if (mux_lseek(hFile, oWhere, SEEK_SET) == (off_t)-1)
         {
             Log.tinyprintf("CHashPage::Read - lseek error %u." ENDLINE, errno);
             continue;
         }
-        int cc = read(hFile, m_pPage, m_nPageSize);
+        int cc = mux_read(hFile, m_pPage, m_nPageSize);
 #endif // HAVE_PREAD
         if ((int)m_nPageSize != cc)
         {
@@ -1182,7 +1198,9 @@ bool CHashPage::ReadPage(HANDLE hFile, HF_FILEOFFSET oWhere)
 }
 #endif // WIN32
 
-HP_DIRINDEX CHashPage::GetDepth(void)
+#endif // MEMORY_BASED
+
+UINT32 CHashPage::GetDepth(void)
 {
     return m_pHeader->m_nDepth;
 }
@@ -1203,9 +1221,9 @@ bool CHashPage::Defrag(HP_HEAPLENGTH nExtra)
 
     // Figure out what a good directory size is given the actual records in this page.
     //
-    int   nRecords;
+    int           nRecords;
     HP_HEAPLENGTH nAllocatedSize;
-    int   nGoodDirSize;
+    UINT32        nGoodDirSize;
     GetStats(nExtra, &nRecords, &nAllocatedSize, &nGoodDirSize);
 
     // Initialize that type of HashPage and copy records over.
@@ -1248,7 +1266,7 @@ void CHashPage::SetVariablePointers(void)
     m_nDirEmptyTrigger = (m_pHeader->m_nDirSize)/7;
 }
 
-HP_DIRINDEX CHashPage::FindFirst(HP_PHEAPLENGTH pnRecord, void *pRecord)
+UINT32 CHashPage::FindFirst(HP_PHEAPLENGTH pnRecord, void *pRecord)
 {
     for (m_iDir = 0; m_iDir < m_pHeader->m_nDirSize; m_iDir++)
     {
@@ -1263,9 +1281,9 @@ HP_DIRINDEX CHashPage::FindFirst(HP_PHEAPLENGTH pnRecord, void *pRecord)
     return HP_DIR_EMPTY;
 }
 
-HP_DIRINDEX CHashPage::FindNext(HP_PHEAPLENGTH pnRecord, void *pRecord)
+UINT32 CHashPage::FindNext(HP_PHEAPLENGTH pnRecord, void *pRecord)
 {
-    for ( m_iDir++; m_iDir < m_pHeader->m_nDirSize; m_iDir++)
+    for (m_iDir++; m_iDir < m_pHeader->m_nDirSize; m_iDir++)
     {
         if (m_pDirectory[m_iDir] < HP_DIR_DELETED) // ValidateAllocatedBlock(iDir))
         {
@@ -1278,6 +1296,8 @@ HP_DIRINDEX CHashPage::FindNext(HP_PHEAPLENGTH pnRecord, void *pRecord)
     return HP_DIR_EMPTY;
 }
 
+#if !defined(MEMORY_BASED)
+
 CHashFile::CHashFile(void)
 {
     SeedRandomNumberGenerator();
@@ -1288,8 +1308,13 @@ CHashFile::CHashFile(void)
 
 void CHashFile::Init(void)
 {
+#ifdef WIN32
     m_hDirFile = INVALID_HANDLE_VALUE;
     m_hPageFile = INVALID_HANDLE_VALUE;
+#else
+    m_hDirFile = MUX_OPEN_INVALID_HANDLE_VALUE;
+    m_hPageFile = MUX_OPEN_INVALID_HANDLE_VALUE;
+#endif
     m_nDir = 0;
     m_nDirDepth = 0;
     m_pDir = NULL;
@@ -1301,7 +1326,10 @@ void CHashFile::Init(void)
 #ifdef WIN32
 void CHashFile::WriteDirectory(void)
 {
-    if (m_hDirFile == INVALID_HANDLE_VALUE) return;
+    if (INVALID_HANDLE_VALUE == m_hDirFile)
+    {
+        return;
+    }
 
     SetFilePointer(m_hDirFile, 0, 0, FILE_BEGIN);
     DWORD nWritten;
@@ -1317,13 +1345,16 @@ void CHashFile::WriteDirectory(void)
 #else // WIN32
 void CHashFile::WriteDirectory(void)
 {
-    if (m_hDirFile == INVALID_HANDLE_VALUE) return;
+    if (MUX_OPEN_INVALID_HANDLE_VALUE == m_hDirFile)
+    {
+        return;
+    }
 
 #ifdef HAVE_PWRITE
     pwrite(m_hDirFile, m_pDir, sizeof(HF_FILEOFFSET)*m_nDir, 0);
 #else
-    lseek(m_hDirFile, 0, SEEK_SET);
-    write(m_hDirFile, m_pDir, sizeof(HF_FILEOFFSET)*m_nDir);
+    mux_lseek(m_hDirFile, 0, SEEK_SET);
+    mux_write(m_hDirFile, m_pDir, sizeof(HF_FILEOFFSET)*m_nDir);
 #endif // HAVE_PWRITE
     //SetEndOfFile(m_hDirFile);
 #ifdef DO_COMMIT
@@ -1357,10 +1388,39 @@ bool CHashFile::InitializeDirectory(unsigned int n)
         n >>= 1;
     }
 
-    m_pDir = new HF_FILEOFFSET[m_nDir];
-    ISOUTOFMEMORY(m_pDir);
-    m_hpCacheLookup = new int[m_nDir];
-    ISOUTOFMEMORY(m_hpCacheLookup);
+    m_pDir = NULL;
+    try
+    {
+        m_pDir = new HF_FILEOFFSET[m_nDir];
+    }
+    catch (...)
+    {
+        ; // Nothing.
+    }
+    if (NULL == m_pDir)
+    {
+        return false;
+    }
+
+    m_hpCacheLookup = NULL;
+    try
+    {
+        m_hpCacheLookup = new int[m_nDir];
+    }
+    catch (...)
+    {
+        ; // Nothing.
+    }
+
+    if (NULL == m_hpCacheLookup)
+    {
+        if (m_pDir)
+        {
+            delete [] m_pDir;
+            m_pDir = NULL;
+        }
+        return false;
+    }
 
     for (unsigned int i = 0; i < m_nDir; i++)
     {
@@ -1374,15 +1434,18 @@ bool CHashFile::InitializeDirectory(unsigned int n)
 bool CHashFile::CreateFileSet(const char *szDirFile, const char *szPageFile)
 {
     CloseAll();
+
+    bool bSuccess;
 #ifdef WIN32
     m_hPageFile = CreateFile(szPageFile, GENERIC_READ | GENERIC_WRITE,
         FILE_SHARE_READ, 0, CREATE_ALWAYS,
         FILE_ATTRIBUTE_NORMAL + FILE_FLAG_RANDOM_ACCESS, NULL);
+    bSuccess = (INVALID_HANDLE_VALUE != m_hPageFile);
 #else // WIN32
-    m_hPageFile = open(szPageFile, O_RDWR|O_BINARY|O_CREAT|O_TRUNC, 0600);
+    bSuccess = mux_open(&m_hPageFile, szPageFile, O_RDWR|O_BINARY|O_CREAT|O_TRUNC);
 #endif // WIN32
 
-    if (m_hPageFile == INVALID_HANDLE_VALUE)
+    if (!bSuccess)
     {
         return false;
     }
@@ -1391,11 +1454,12 @@ bool CHashFile::CreateFileSet(const char *szDirFile, const char *szPageFile)
     m_hDirFile = CreateFile(szDirFile, GENERIC_READ | GENERIC_WRITE,
         FILE_SHARE_READ, 0, CREATE_ALWAYS,
         FILE_ATTRIBUTE_NORMAL + FILE_FLAG_SEQUENTIAL_SCAN, NULL);
+    bSuccess = (INVALID_HANDLE_VALUE != m_hDirFile);
 #else // WIN32
-    m_hDirFile = open(szDirFile, O_RDWR|O_BINARY|O_CREAT|O_TRUNC, 0600);
+    bSuccess = mux_open(&m_hDirFile, szDirFile, O_RDWR|O_BINARY|O_CREAT|O_TRUNC);
 #endif // WIN32
 
-    if (m_hPageFile == INVALID_HANDLE_VALUE)
+    if (!bSuccess)
     {
         return false;
     }
@@ -1501,7 +1565,7 @@ bool CHashFile::ReadDirectory(void)
 #ifdef WIN32
     UINT32 cc = SetFilePointer(m_hDirFile, 0, 0, FILE_END);
 #else // WIN32
-    UINT32 cc = lseek(m_hDirFile, 0, SEEK_END);
+    UINT32 cc = mux_lseek(m_hDirFile, 0, SEEK_END);
 #endif // WIN32
     if (cc == 0xFFFFFFFFUL)
     {
@@ -1513,13 +1577,16 @@ bool CHashFile::ReadDirectory(void)
 #ifdef WIN32
     cc = SetFilePointer(m_hDirFile, 0, 0, FILE_BEGIN);
     DWORD nRead;
-    ReadFile(m_hDirFile, m_pDir, sizeof(HF_FILEOFFSET)*m_nDir, &nRead, 0);
+    if (!ReadFile(m_hDirFile, m_pDir, sizeof(HF_FILEOFFSET)*m_nDir, &nRead, 0))
+    {
+        return false;
+    }
 #else // WIN32
 #ifdef HAVE_PREAD
     pread(m_hDirFile, m_pDir, sizeof(HF_FILEOFFSET)*m_nDir, 0);
 #else
-    lseek(m_hDirFile, 0, SEEK_SET);
-    read(m_hDirFile, m_pDir, sizeof(HF_FILEOFFSET)*m_nDir);
+    mux_lseek(m_hDirFile, 0, SEEK_SET);
+    mux_read(m_hDirFile, m_pDir, sizeof(HF_FILEOFFSET)*m_nDir);
 #endif // HAVE_PREAD
 #endif // WIN32
     return true;
@@ -1558,14 +1625,16 @@ int CHashFile::Open(const char *szDirFile, const char *szPageFile, int nCachePag
 
     // First let's try to open the page file. This is the more important file.
     //
+    bool bSuccess;
 #ifdef WIN32
     m_hPageFile = CreateFile(szPageFile, GENERIC_READ | GENERIC_WRITE,
         FILE_SHARE_READ, 0, OPEN_EXISTING,
         FILE_ATTRIBUTE_NORMAL + FILE_FLAG_RANDOM_ACCESS, NULL);
+    bSuccess = (INVALID_HANDLE_VALUE != m_hPageFile);
 #else // WIN32
-    m_hPageFile = open(szPageFile, O_RDWR|O_BINARY);
+    bSuccess = mux_open(&m_hPageFile, szPageFile, O_RDWR|O_BINARY);
 #endif // WIN32
-    if (m_hPageFile == INVALID_HANDLE_VALUE)
+    if (!bSuccess)
     {
         // The PageFile doesn't exist, so we have'ta create both of them.
         //
@@ -1585,7 +1654,7 @@ int CHashFile::Open(const char *szDirFile, const char *szPageFile, int nCachePag
 #ifdef WIN32
     oEndOfFile = SetFilePointer(m_hPageFile, 0, 0, FILE_END);
 #else // WIN32
-    oEndOfFile = lseek(m_hPageFile, 0, SEEK_END);
+    oEndOfFile = mux_lseek(m_hPageFile, 0, SEEK_END);
 #endif // WIN32
     if (oEndOfFile == 0xFFFFFFFFUL)
     {
@@ -1620,10 +1689,11 @@ int CHashFile::Open(const char *szDirFile, const char *szPageFile, int nCachePag
     m_hDirFile = CreateFile(szDirFile, GENERIC_READ | GENERIC_WRITE,
         FILE_SHARE_READ, 0, OPEN_EXISTING,
         FILE_ATTRIBUTE_NORMAL + FILE_FLAG_SEQUENTIAL_SCAN, NULL);
+    bSuccess = (INVALID_HANDLE_VALUE != m_hDirFile);
 #else // WIN32
-    m_hDirFile = open(szDirFile, O_RDWR|O_BINARY);
+    bSuccess = mux_open(&m_hDirFile, szDirFile, O_RDWR|O_BINARY);
 #endif // WIN32
-    if (m_hDirFile == INVALID_HANDLE_VALUE)
+    if (!bSuccess)
     {
         // The Directory doesn't exist, so we create it anew, and rebuild the
         // index.
@@ -1631,11 +1701,12 @@ int CHashFile::Open(const char *szDirFile, const char *szPageFile, int nCachePag
         m_hDirFile = CreateFile(szDirFile, GENERIC_READ | GENERIC_WRITE,
             FILE_SHARE_READ, 0, CREATE_ALWAYS,
             FILE_ATTRIBUTE_NORMAL + FILE_FLAG_SEQUENTIAL_SCAN, NULL);
+        bSuccess = (INVALID_HANDLE_VALUE != m_hDirFile);
 #else // WIN32
-        m_hDirFile = open(szDirFile, O_RDWR|O_BINARY|O_CREAT|O_TRUNC, 0600);
+        bSuccess = mux_open(&m_hDirFile, szDirFile, O_RDWR|O_BINARY|O_CREAT|O_TRUNC);
 #endif // WIN32
 
-        if (m_hPageFile == INVALID_HANDLE_VALUE)
+        if (!bSuccess)
         {
             CloseAll();
             return HF_OPEN_STATUS_ERROR;
@@ -1661,7 +1732,11 @@ int CHashFile::Open(const char *szDirFile, const char *szPageFile, int nCachePag
 
 void CHashFile::Sync(void)
 {
-    if (m_hPageFile != INVALID_HANDLE_VALUE)
+#ifdef WIN32
+    if (INVALID_HANDLE_VALUE != m_hPageFile)
+#else
+    if (MUX_OPEN_INVALID_HANDLE_VALUE != m_hPageFile)
+#endif
     {
         cs_syncs++;
         bool bAllFlushed = true;
@@ -1689,7 +1764,11 @@ void CHashFile::Sync(void)
 #endif // DO_COMMIT
     }
 #ifdef DO_COMMIT
-    if (  m_hDirFile != INVALID_HANDLE_VALUE
+#ifdef WIN32
+    if (  INVALID_HANDLE_VALUE != m_hDirFile
+#else
+    if (  MUX_OPEN_INVALID_HANDLE_VALUE != m_hDirFile
+#endif
        && !mudstate.bStandAlone)
     {
 #ifdef WIN32
@@ -1703,12 +1782,16 @@ void CHashFile::Sync(void)
 
 void CHashFile::CloseAll(void)
 {
-    if (m_hPageFile != INVALID_HANDLE_VALUE)
+#ifdef WIN32
+    if (INVALID_HANDLE_VALUE != m_hPageFile)
+#else
+    if (MUX_OPEN_INVALID_HANDLE_VALUE != m_hPageFile)
+#endif
     {
         Sync();
         if (m_pDir)
         {
-            delete [] m_pDir;
+            MEMFREE(m_pDir);
             m_pDir = NULL;
         }
         if (m_hpCacheLookup)
@@ -1720,15 +1803,20 @@ void CHashFile::CloseAll(void)
 #ifdef WIN32
         CloseHandle(m_hPageFile);
 #else // WIN32
-        close(m_hPageFile);
+        mux_close(m_hPageFile);
 #endif // WIN32
     }
-    if (m_hDirFile != INVALID_HANDLE_VALUE)
+
+#ifdef WIN32
+    if (INVALID_HANDLE_VALUE != m_hDirFile)
+#else
+    if (MUX_OPEN_INVALID_HANDLE_VALUE != m_hDirFile)
+#endif
     {
 #ifdef WIN32
         CloseHandle(m_hDirFile);
 #else // WIN32
-        close(m_hDirFile);
+        mux_close(m_hDirFile);
 #endif // WIN32
     }
     Init();
@@ -1912,8 +2000,8 @@ bool CHashFile::Insert(HP_HEAPLENGTH nRecord, UINT32 nHash, void *pRecord)
 #ifdef HAVE_PWRITE
         pwrite(m_hDirFile, m_pDir, sizeof(HF_FILEOFFSET)*m_nDir, 0);
 #else
-        lseek(m_hDirFile, 0, SEEK_SET);
-        write(m_hDirFile, m_pDir, sizeof(HF_FILEOFFSET)*m_nDir);
+        mux_lseek(m_hDirFile, 0, SEEK_SET);
+        mux_write(m_hDirFile, m_pDir, sizeof(HF_FILEOFFSET)*m_nDir);
 #endif // HAVE_PWRITE
 #endif // WIN32
 
@@ -1934,13 +2022,42 @@ bool CHashFile::Insert(HP_HEAPLENGTH nRecord, UINT32 nHash, void *pRecord)
 bool CHashFile::DoubleDirectory(void)
 {
     unsigned int nNewDir     = 2 * m_nDir;
-    HP_DIRINDEX nNewDirDepth = m_nDirDepth + 1;
+    UINT32       nNewDirDepth = m_nDirDepth + 1;
 
-    HF_PFILEOFFSET pNewDir = new HF_FILEOFFSET[nNewDir];
-    ISOUTOFMEMORY(pNewDir);
 
-    int *pNewCacheLookup = new int[nNewDir];
-    ISOUTOFMEMORY(pNewCacheLookup);
+    HF_PFILEOFFSET pNewDir = NULL;
+    try
+    {
+        pNewDir = new HF_FILEOFFSET[nNewDir];
+    }
+    catch (...)
+    {
+        ; // Nothing.
+    }
+    if (NULL == pNewDir)
+    {
+        return false;
+    }
+
+    int *pNewCacheLookup = NULL;
+    try
+    {
+        pNewCacheLookup = new int[nNewDir];
+    }
+    catch (...)
+    {
+        ; // Nothing.
+    }
+
+    if (NULL == pNewCacheLookup)
+    {
+        if (pNewDir)
+        {
+            delete [] pNewDir;
+            pNewDir = NULL;
+        }
+        return false;
+    }
 
     unsigned int iNewDir = 0;
     for (unsigned int iDir = 0; iDir < m_nDir; iDir++)
@@ -1968,7 +2085,7 @@ bool CHashFile::DoubleDirectory(void)
     return true;
 }
 
-HP_DIRINDEX CHashFile::FindFirstKey(UINT32 nHash)
+UINT32 CHashFile::FindFirstKey(UINT32 nHash)
 {
     cs_reads++;
 
@@ -1995,7 +2112,7 @@ HP_DIRINDEX CHashFile::FindFirstKey(UINT32 nHash)
     }
 
     unsigned int numchecks;
-    HP_DIRINDEX iDir = m_Cache[iCache].m_hp.FindFirstKey(nHash, &numchecks);
+    UINT32 iDir = m_Cache[iCache].m_hp.FindFirstKey(nHash, &numchecks);
 
     if (iDir == HP_DIR_EMPTY)
     {
@@ -2005,7 +2122,7 @@ HP_DIRINDEX CHashFile::FindFirstKey(UINT32 nHash)
     return iDir;
 }
 
-HP_DIRINDEX CHashFile::FindNextKey(HP_DIRINDEX iDir, UINT32 nHash)
+UINT32 CHashFile::FindNextKey(UINT32 iDir, UINT32 nHash)
 {
     cs_reads++;
 
@@ -2021,12 +2138,12 @@ HP_DIRINDEX CHashFile::FindNextKey(HP_DIRINDEX iDir, UINT32 nHash)
     return iDir;
 }
 
-void CHashFile::Copy(HP_DIRINDEX iDir, HP_PHEAPLENGTH pnRecord, void *pRecord)
+void CHashFile::Copy(UINT32 iDir, HP_PHEAPLENGTH pnRecord, void *pRecord)
 {
     m_Cache[iCache].m_hp.HeapCopy(iDir, pnRecord, pRecord);
 }
 
-void CHashFile::Remove(HP_DIRINDEX iDir)
+void CHashFile::Remove(UINT32 iDir)
 {
     cs_dels++;
     m_Cache[iCache].m_hp.HeapFree(iDir);
@@ -2200,6 +2317,8 @@ int CHashFile::ReadCache(UINT32 iFileDir, int *phits)
     return -1;
 }
 
+#endif // MEMORY_BASED
+
 CHashTable::CHashTable(void)
 {
     SeedRandomNumberGenerator();
@@ -2374,7 +2493,7 @@ bool CHashTable::DoubleDirectory(void)
     return false;
 }
 
-HP_DIRINDEX CHashTable::FindFirstKey(UINT32  nHash)
+UINT32 CHashTable::FindFirstKey(UINT32  nHash)
 {
     m_nScans++;
     UINT32  iTableDir = nHash >> (32-m_nDirDepth);
@@ -2402,7 +2521,7 @@ HP_DIRINDEX CHashTable::FindFirstKey(UINT32  nHash)
 #endif // HP_PROTECTION
     unsigned int numchecks;
 
-    HP_DIRINDEX iDir = m_hpLast->FindFirstKey(nHash, &numchecks);
+    UINT32 iDir = m_hpLast->FindFirstKey(nHash, &numchecks);
 
     m_nChecks += numchecks;
     if (numchecks > m_nMaxScan)
@@ -2417,7 +2536,7 @@ HP_DIRINDEX CHashTable::FindFirstKey(UINT32  nHash)
     return iDir;
 }
 
-HP_DIRINDEX CHashTable::FindNextKey(HP_DIRINDEX iDir, UINT32  nHash)
+UINT32 CHashTable::FindNextKey(UINT32 iDir, UINT32  nHash)
 {
     m_nScans++;
     unsigned int numchecks;
@@ -2437,19 +2556,19 @@ HP_DIRINDEX CHashTable::FindNextKey(HP_DIRINDEX iDir, UINT32  nHash)
     return iDir;
 }
 
-void CHashTable::Copy(HP_DIRINDEX iDir, HP_PHEAPLENGTH pnRecord, void *pRecord)
+void CHashTable::Copy(UINT32 iDir, HP_PHEAPLENGTH pnRecord, void *pRecord)
 {
     m_hpLast->HeapCopy(iDir, pnRecord, pRecord);
 }
 
-void CHashTable::Remove(HP_DIRINDEX iDir)
+void CHashTable::Remove(UINT32 iDir)
 {
     m_nEntries--;
     m_nDeletions++;
     m_hpLast->HeapFree(iDir);
 }
 
-void CHashTable::Update(HP_DIRINDEX iDir, HP_HEAPLENGTH nRecord, void *pRecord)
+void CHashTable::Update(UINT32 iDir, HP_HEAPLENGTH nRecord, void *pRecord)
 {
     m_hpLast->HeapUpdate(iDir, nRecord, pRecord);
 }
@@ -2485,7 +2604,7 @@ void CHashTable::Reset(void)
     Init();
 }
 
-HP_DIRINDEX CHashTable::FindFirst(HP_PHEAPLENGTH pnRecord, void *pRecord)
+UINT32 CHashTable::FindFirst(HP_PHEAPLENGTH pnRecord, void *pRecord)
 {
     m_hpLast = 0;
     for (m_iPage = 0; m_iPage < m_nDir; m_iPage++)
@@ -2494,7 +2613,7 @@ HP_DIRINDEX CHashTable::FindFirst(HP_PHEAPLENGTH pnRecord, void *pRecord)
         m_hpLast = m_pDir[m_iPage];
         if (m_hpLast)
         {
-            HP_DIRINDEX iDir = m_hpLast->FindFirst(pnRecord, pRecord);
+            UINT32 iDir = m_hpLast->FindFirst(pnRecord, pRecord);
             if (iDir != HP_DIR_EMPTY)
             {
                 return iDir;
@@ -2504,11 +2623,11 @@ HP_DIRINDEX CHashTable::FindFirst(HP_PHEAPLENGTH pnRecord, void *pRecord)
     return HF_FIND_END;
 }
 
-HP_DIRINDEX CHashTable::FindNext(HP_PHEAPLENGTH pnRecord, void *pRecord)
+UINT32 CHashTable::FindNext(HP_PHEAPLENGTH pnRecord, void *pRecord)
 {
     if (m_hpLast)
     {
-        HP_DIRINDEX iDir = m_hpLast->FindNext(pnRecord, pRecord);
+        UINT32 iDir = m_hpLast->FindNext(pnRecord, pRecord);
         if (iDir != HP_DIR_EMPTY)
         {
             return iDir;
@@ -2525,7 +2644,7 @@ HP_DIRINDEX CHashTable::FindNext(HP_PHEAPLENGTH pnRecord, void *pRecord)
         m_hpLast = m_pDir[m_iPage];
         if (m_hpLast)
         {
-            HP_DIRINDEX iDir = m_hpLast->FindFirst(pnRecord, pRecord);
+            UINT32 iDir = m_hpLast->FindFirst(pnRecord, pRecord);
             if (iDir != HP_DIR_EMPTY)
             {
                 return iDir;
@@ -2535,7 +2654,7 @@ HP_DIRINDEX CHashTable::FindNext(HP_PHEAPLENGTH pnRecord, void *pRecord)
     return HF_FIND_END;
 }
 
-INT64 CHashTable::GetEntryCount()
+unsigned int CHashTable::GetEntryCount()
 {
     return m_nEntries;
 }
@@ -2614,12 +2733,12 @@ void CLogFile::WriteString(const char *pString)
     WriteBuffer(nString, pString);
 }
 
-void DCL_CDECL CLogFile::tinyprintf(char *fmt, ...)
+void DCL_CDECL CLogFile::tinyprintf(const char *fmt, ...)
 {
     va_list ap;
     va_start(ap, fmt);
     char aTempBuffer[SIZEOF_LOG_BUFFER];
-    int nString = mux_vsnprintf(aTempBuffer, SIZEOF_LOG_BUFFER, fmt, ap);
+    size_t nString = mux_vsnprintf(aTempBuffer, SIZEOF_LOG_BUFFER, fmt, ap);
     va_end(ap);
     WriteBuffer(nString, aTempBuffer);
 }
@@ -2629,74 +2748,85 @@ static void MakeLogName
     const char *pBasename,
     const char *szPrefix,
     CLinearTimeAbsolute lta,
-    char *szLogName
+    char *szLogName,
+    size_t nLogName
 )
 {
     char szTimeStamp[18];
-    lta.ReturnUniqueString(szTimeStamp);
+    lta.ReturnUniqueString(szTimeStamp, sizeof(szTimeStamp));
     if (  pBasename
        && pBasename[0] != '\0')
     {
-        sprintf(szLogName, "%s/%s-%s.log",
+        mux_sprintf(szLogName, nLogName, "%s/%s-%s.log",
             pBasename,
             szPrefix,
             szTimeStamp);
     }
     else
     {
-        sprintf(szLogName, "%s-%s.log",
+        mux_sprintf(szLogName, nLogName, "%s-%s.log",
             szPrefix,
             szTimeStamp);
     }
 }
 
-void CLogFile::CreateLogFile(void)
+bool CLogFile::CreateLogFile(void)
 {
     CloseLogFile();
 
     m_nSize = 0;
+
+    bool bSuccess;
 #ifdef WIN32
     m_hFile = CreateFile(m_szFilename, GENERIC_READ | GENERIC_WRITE,
         FILE_SHARE_READ, 0, CREATE_ALWAYS,
         FILE_ATTRIBUTE_NORMAL + FILE_FLAG_SEQUENTIAL_SCAN, NULL);
+    bSuccess = (INVALID_HANDLE_VALUE != m_hFile);
 #else // WIN32
-    m_hFile = open(m_szFilename, O_RDWR|O_BINARY|O_CREAT|O_TRUNC, 0600);
+    bSuccess = mux_open(&m_fdFile, m_szFilename, O_RDWR|O_BINARY|O_CREAT|O_TRUNC);
 #endif // WIN32
+    return bSuccess;
 }
 
 void CLogFile::AppendLogFile(void)
 {
     CloseLogFile();
 
+    bool bSuccess;
 #ifdef WIN32
     m_hFile = CreateFile(m_szFilename, GENERIC_READ | GENERIC_WRITE,
         FILE_SHARE_READ, 0, OPEN_ALWAYS,
         FILE_ATTRIBUTE_NORMAL + FILE_FLAG_SEQUENTIAL_SCAN, NULL);
+    bSuccess = (INVALID_HANDLE_VALUE != m_hFile);
 #else // WIN32
-    m_hFile = open(m_szFilename, O_RDWR|O_BINARY, 0600);
+    bSuccess = mux_open(&m_fdFile, m_szFilename, O_RDWR|O_BINARY);
 #endif // WIN32
 
-    if (m_hFile != INVALID_HANDLE_VALUE)
+    if (bSuccess)
     {
 #ifdef WIN32
         SetFilePointer(m_hFile, 0, 0, FILE_END);
 #else // WIN32
-        lseek(m_hFile, 0, SEEK_SET);
+        mux_lseek(m_fdFile, 0, SEEK_END);
 #endif // WIN32
     }
 }
 
 void CLogFile::CloseLogFile(void)
 {
-    if (m_hFile != INVALID_HANDLE_VALUE)
-    {
 #ifdef WIN32
+    if (INVALID_HANDLE_VALUE != m_hFile)
+    {
         CloseHandle(m_hFile);
-#else // WIN32
-        close(m_hFile);
-#endif // WIN32
         m_hFile = INVALID_HANDLE_VALUE;
     }
+#else
+    if (MUX_OPEN_INVALID_HANDLE_VALUE != m_fdFile)
+    {
+        mux_close(m_fdFile);
+        m_fdFile = MUX_OPEN_INVALID_HANDLE_VALUE;
+    }
+#endif
 }
 
 #define FILE_SIZE_TRIGGER (512*1024UL)
@@ -2719,7 +2849,7 @@ void CLogFile::Flush(void)
         unsigned long nWritten;
         WriteFile(m_hFile, m_aBuffer, (DWORD)m_nBuffer, &nWritten, NULL);
 #else // WIN32
-        write(m_hFile, m_aBuffer, m_nBuffer);
+        mux_write(m_fdFile, m_aBuffer, m_nBuffer);
 #endif // WIN32
 
         if (m_nSize > FILE_SIZE_TRIGGER)
@@ -2727,7 +2857,8 @@ void CLogFile::Flush(void)
             CloseLogFile();
 
             m_ltaStarted.GetLocal();
-            MakeLogName(m_pBasename, m_szPrefix, m_ltaStarted, m_szFilename);
+            MakeLogName(m_pBasename, m_szPrefix, m_ltaStarted, m_szFilename,
+                sizeof(m_szFilename));
 
             CreateLogFile();
         }
@@ -2746,13 +2877,13 @@ void CLogFile::SetPrefix(const char *szPrefix)
         }
 
         char szNewName[SIZEOF_PATHNAME];
-        MakeLogName(m_pBasename, szPrefix, m_ltaStarted, szNewName);
+        MakeLogName(m_pBasename, szPrefix, m_ltaStarted, szNewName, sizeof(szNewName));
         if (bEnabled)
         {
             ReplaceFile(m_szFilename, szNewName);
         }
-        strcpy(m_szPrefix, szPrefix);
-        strcpy(m_szFilename, szNewName);
+        mux_strncpy(m_szPrefix, szPrefix, 31);
+        mux_strncpy(m_szFilename, szNewName, SIZEOF_PATHNAME-1);
 
         if (bEnabled)
         {
@@ -2794,7 +2925,11 @@ CLogFile::CLogFile(void)
 #endif // WIN32
 
     m_ltaStarted.GetLocal();
+#ifdef WIN32
     m_hFile = INVALID_HANDLE_VALUE;
+#else
+    m_fdFile = MUX_OPEN_INVALID_HANDLE_VALUE;
+#endif
     m_nSize = 0;
     m_nBuffer = 0;
     bEnabled = false;
@@ -2809,7 +2944,8 @@ void CLogFile::StartLogging()
     if (!bUseStderr)
     {
         m_ltaStarted.GetLocal();
-        MakeLogName(m_pBasename, m_szPrefix, m_ltaStarted, m_szFilename);
+        MakeLogName(m_pBasename, m_szPrefix, m_ltaStarted, m_szFilename,
+            sizeof(m_szFilename));
         CreateLogFile();
     }
     bEnabled = true;
@@ -2888,7 +3024,7 @@ bool SubtractSpaceFromFileLine
 {
     *pnSpace = 0;
     *pAllocLine = -1;
-    HP_DIRINDEX iDir = hfIdentData.FindFirstKey(nHash);
+    UINT32 iDir = hfIdentData.FindFirstKey(nHash);
     if (iDir != HF_FIND_END)
     {
         HP_HEAPLENGTH nIdent;
@@ -2923,7 +3059,7 @@ unsigned long AddSpaceToFileLine
     UINT32 nHash = HashFileLine(file, line);
     bool bFound = false;
 again:
-    HP_DIRINDEX iDir = hfIdentData.FindFirstKey(nHash);
+    UINT32 iDir = hfIdentData.FindFirstKey(nHash);
     while (iDir != HF_FIND_END)
     {
         hfIdentData.Copy(iDir, &nIdent, Buffer);
@@ -2961,7 +3097,7 @@ void AccountForAllocation(void *pointer, size_t size, const char *file, int line
 
     unsigned long nHash = HashPointer(pointer);
 again:
-    HP_DIRINDEX iDir = hfAllocData.FindFirstKey(nHash);
+    UINT32 iDir = hfAllocData.FindFirstKey(nHash);
 
     while (iDir != HF_FIND_END)
     {
@@ -2992,7 +3128,7 @@ void AccountForFree(void *pointer, const char *file, int line)
 
     bool bFound = false;
 again:
-    HP_DIRINDEX iDir = hfAllocData.FindFirstKey(nHash);
+    UINT32 iDir = hfAllocData.FindFirstKey(nHash);
     while (iDir != HF_FIND_END)
     {
         // We found it.
