@@ -1,6 +1,6 @@
 // wiz.cpp -- Wizard-only commands.
 //
-// $Id: wiz.cpp,v 1.16 2006/01/07 01:24:27 sdennis Exp $
+// $Id: wiz.cpp 492 2006-11-30 17:12:25Z brazilofmux $
 //
 
 #include "copyright.h"
@@ -144,7 +144,7 @@ static void do_teleport_single
             }
             did_it(victim, destination,
                    A_TFAIL, "You can't teleport there!",
-                   A_OTFAIL, 0, A_ATFAIL, (char **)NULL, 0);
+                   A_OTFAIL, 0, A_ATFAIL, 0, NULL, 0);
             return;
         }
 
@@ -176,7 +176,7 @@ static void do_teleport_single
             }
             did_it(victim, destination,
                    A_TFAIL, "You can't teleport there!",
-                   A_OTFAIL, 0, A_ATFAIL, (char **)NULL, 0);
+                   A_OTFAIL, 0, A_ATFAIL, 0, NULL, 0);
             return;
         }
         else
@@ -263,8 +263,8 @@ void do_teleport
 // ---------------------------------------------------------------------------
 // do_force_prefixed: Interlude to do_force for the # command
 //
-void do_force_prefixed( dbref executor, dbref caller, dbref enactor, int key,
-                        char *command, char *args[], int nargs )
+void do_force_prefixed( dbref executor, dbref caller, dbref enactor, int eval,
+                        int key, char *command, char *args[], int nargs )
 {
     char *cp = parse_to(&command, ' ', 0);
     if (!command)
@@ -277,14 +277,14 @@ void do_force_prefixed( dbref executor, dbref caller, dbref enactor, int key,
     }
     if (*command)
     {
-        do_force(executor, caller, enactor, key, cp, command, args, nargs);
+        do_force(executor, caller, enactor, eval, key, cp, command, args, nargs);
     }
 }
 
 // ---------------------------------------------------------------------------
 // do_force: Force an object to do something.
 //
-void do_force( dbref executor, dbref caller, dbref enactor, int key,
+void do_force( dbref executor, dbref caller, dbref enactor, int eval, int key,
                char *what, char *command, char *args[], int nargs )
 {
     UNUSED_PARAMETER(enactor);
@@ -296,8 +296,10 @@ void do_force( dbref executor, dbref caller, dbref enactor, int key,
         // Force victim to do command.
         //
         CLinearTimeAbsolute lta;
-        wait_que(victim, caller, executor, false, lta, NOTHING, 0, command,
-            args, nargs, mudstate.global_regs);
+        wait_que(victim, caller, executor, eval, false, lta, NOTHING, 0,
+            command,
+            nargs, args,
+            mudstate.global_regs);
     }
 }
 
@@ -394,15 +396,17 @@ void do_toad
     //
     loc = Location(victim);
     buf = alloc_mbuf("do_toad");
-    const char *pVictimName = Name(victim);
-    sprintf(buf, "%s has been turned into a slimy toad!", pVictimName);
+    const char *pVictimName = Moniker(victim);
+    mux_sprintf(buf, MBUF_SIZE, "%s has been turned into a slimy toad!",
+        pVictimName);
     notify_except2(loc, executor, victim, executor, buf);
-    sprintf(buf, "You toaded %s! (%d objects @chowned)", pVictimName, count + 1);
+    mux_sprintf(buf, MBUF_SIZE, "You toaded %s! (%d objects @chowned)",
+        pVictimName, count + 1);
     notify_quiet(executor, buf);
 
     // Zap the name from the name hash table.
     //
-    sprintf(buf, "a slimy toad named %s", pVictimName);
+    mux_sprintf(buf, MBUF_SIZE, "a slimy toad named %s", pVictimName);
     delete_player_name(victim, pVictimName);
     s_Name(victim, buf);
     free_mbuf(buf);
@@ -494,15 +498,16 @@ void do_newpassword
     notify_quiet(executor, "Password changed.");
     char *buf = alloc_lbuf("do_newpassword");
     char *bp = buf;
-    safe_tprintf_str(buf, &bp, "Your password has been changed by %s.", Name(executor));
+    safe_tprintf_str(buf, &bp, "Your password has been changed by %s.", Moniker(executor));
     notify_quiet(victim, buf);
     free_lbuf(buf);
 }
 
-void do_boot(dbref executor, dbref caller, dbref enactor, int key, char *name)
+void do_boot(dbref executor, dbref caller, dbref enactor, int eval, int key, char *name)
 {
     UNUSED_PARAMETER(caller);
     UNUSED_PARAMETER(enactor);
+    UNUSED_PARAMETER(eval);
 
     if (!Can_Boot(executor))
     {
@@ -557,7 +562,7 @@ void do_boot(dbref executor, dbref caller, dbref enactor, int key, char *name)
         log_text(" was @booted by ");
         log_name(executor);
         ENDLOG;
-        notify_quiet(executor, tprintf("You booted %s off!", Name(victim)));
+        notify_quiet(executor, tprintf("You booted %s off!", Moniker(victim)));
     }
 
     const char *buf;
@@ -567,7 +572,7 @@ void do_boot(dbref executor, dbref caller, dbref enactor, int key, char *name)
     }
     else
     {
-        buf = tprintf("%s gently shows you the door.", Name(executor));
+        buf = tprintf("%s gently shows you the door.", Moniker(executor));
     }
 
     if (key & BOOT_PORT)
@@ -584,11 +589,12 @@ void do_boot(dbref executor, dbref caller, dbref enactor, int key, char *name)
 // ---------------------------------------------------------------------------
 // do_poor: Reduce the wealth of anyone over a specified amount.
 //
-void do_poor(dbref executor, dbref caller, dbref enactor, int key, char *arg1)
+void do_poor(dbref executor, dbref caller, dbref enactor, int eval, int key, char *arg1)
 {
     UNUSED_PARAMETER(executor);
     UNUSED_PARAMETER(caller);
     UNUSED_PARAMETER(enactor);
+    UNUSED_PARAMETER(eval);
     UNUSED_PARAMETER(key);
 
     if (!is_rational(arg1))
@@ -615,10 +621,11 @@ void do_poor(dbref executor, dbref caller, dbref enactor, int key, char *arg1)
 // ---------------------------------------------------------------------------
 // do_cut: Chop off a contents or exits chain after the named item.
 //
-void do_cut(dbref executor, dbref caller, dbref enactor, int key, char *thing)
+void do_cut(dbref executor, dbref caller, dbref enactor, int eval, int key, char *thing)
 {
     UNUSED_PARAMETER(caller);
     UNUSED_PARAMETER(enactor);
+    UNUSED_PARAMETER(eval);
     UNUSED_PARAMETER(key);
 
     dbref object = match_controlled(executor, thing);
@@ -632,10 +639,11 @@ void do_cut(dbref executor, dbref caller, dbref enactor, int key, char *thing)
 // --------------------------------------------------------------------------
 // do_motd: Wizard-settable message of the day (displayed on connect)
 //
-void do_motd(dbref executor, dbref caller, dbref enactor, int key, char *message)
+void do_motd(dbref executor, dbref caller, dbref enactor, int eval, int key, char *message)
 {
     UNUSED_PARAMETER(caller);
     UNUSED_PARAMETER(enactor);
+    UNUSED_PARAMETER(eval);
 
     bool is_brief = false;
 
@@ -652,8 +660,7 @@ void do_motd(dbref executor, dbref caller, dbref enactor, int key, char *message
     {
     case MOTD_ALL:
 
-        strncpy(mudconf.motd_msg, message, GBUF_SIZE-1);
-        mudconf.motd_msg[GBUF_SIZE-1] = '\0';
+        mux_strncpy(mudconf.motd_msg, message, GBUF_SIZE-1);
         if (!Quiet(executor))
         {
             notify_quiet(executor, "Set: MOTD.");
@@ -662,8 +669,7 @@ void do_motd(dbref executor, dbref caller, dbref enactor, int key, char *message
 
     case MOTD_WIZ:
 
-        strncpy(mudconf.wizmotd_msg, message, GBUF_SIZE-1);
-        mudconf.wizmotd_msg[GBUF_SIZE-1] = '\0';
+        mux_strncpy(mudconf.wizmotd_msg, message, GBUF_SIZE-1);
         if (!Quiet(executor))
         {
             notify_quiet(executor, "Set: Wizard MOTD.");
@@ -672,8 +678,7 @@ void do_motd(dbref executor, dbref caller, dbref enactor, int key, char *message
 
     case MOTD_DOWN:
 
-        strncpy(mudconf.downmotd_msg, message, GBUF_SIZE-1);
-        mudconf.downmotd_msg[GBUF_SIZE-1] = '\0';
+        mux_strncpy(mudconf.downmotd_msg, message, GBUF_SIZE-1);
         if (!Quiet(executor))
         {
             notify_quiet(executor, "Set: Down MOTD.");
@@ -682,8 +687,7 @@ void do_motd(dbref executor, dbref caller, dbref enactor, int key, char *message
 
     case MOTD_FULL:
 
-        strncpy(mudconf.fullmotd_msg, message, GBUF_SIZE-1);
-        mudconf.fullmotd_msg[GBUF_SIZE-1] = '\0';
+        mux_strncpy(mudconf.fullmotd_msg, message, GBUF_SIZE-1);
         if (!Quiet(executor))
         {
             notify_quiet(executor, "Set: Full MOTD.");
@@ -750,10 +754,11 @@ NAMETAB enable_names[] =
     { NULL,             0,  0,          0}
 };
 
-void do_global(dbref executor, dbref caller, dbref enactor, int key, char *flag)
+void do_global(dbref executor, dbref caller, dbref enactor, int eval, int key, char *flag)
 {
     UNUSED_PARAMETER(caller);
     UNUSED_PARAMETER(enactor);
+    UNUSED_PARAMETER(eval);
 
     // Set or clear the indicated flag.
     //
